@@ -1,9 +1,12 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/Modules/AdminGenericInterfaceMappingSimple.pm - provides a TransportHTTPSOAP view for admins
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# --
+# $Id: AdminGenericInterfaceMappingSimple.pm,v 1.21 2012-04-20 00:19:42 ep Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Modules::AdminGenericInterfaceMappingSimple;
@@ -11,10 +14,15 @@ package Kernel::Modules::AdminGenericInterfaceMappingSimple;
 use strict;
 use warnings;
 
-use Kernel::System::VariableCheck qw(:all);
-use Kernel::Language qw(Translatable);
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.21 $) [1];
 
-our $ObjectManagerDisabled = 1;
+use Kernel::System::VariableCheck qw(:all);
+use Kernel::System::GenericInterface::Webservice;
+use Kernel::System::Valid;
+use YAML;
+
+use Kernel::System::VariableCheck qw(:all);
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -22,7 +30,19 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
-    $Self->{DeletedString} = '_GenericInterface_Mapping_Simple_DeletedString_Dont_Use_It_String_Please';
+    for (qw(ParamObject LayoutObject LogObject ConfigObject)) {
+        if ( !$Self->{$_} ) {
+            $Self->{LayoutObject}->FatalError( Message => "Got no $_!" );
+        }
+    }
+
+    # create additional objects
+    $Self->{ValidObject} = Kernel::System::Valid->new( %{$Self} );
+    $Self->{WebserviceObject} =
+        Kernel::System::GenericInterface::Webservice->new( %{$Self} );
+
+    $Self->{DeletedString}
+        = '_GenericInterface_Mapping_Simple_DeletedString_Dont_Use_It_String_Please';
 
     return $Self;
 }
@@ -30,78 +50,75 @@ sub new {
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    my $ParamObject = $Kernel::OM->Get('Kernel::System::Web::Request');
-
-    my $WebserviceID = $ParamObject->GetParam( Param => 'WebserviceID' ) || '';
-    my $Operation    = $ParamObject->GetParam( Param => 'Operation' )    || '';
-    my $Invoker      = $ParamObject->GetParam( Param => 'Invoker' )      || '';
-    my $Direction    = $ParamObject->GetParam( Param => 'Direction' )    || '';
+    my $WebserviceID = $Self->{ParamObject}->GetParam( Param => 'WebserviceID' )
+        || '';
+    my $Operation = $Self->{ParamObject}->GetParam( Param => 'Operation' )
+        || '';
+    my $Invoker = $Self->{ParamObject}->GetParam( Param => 'Invoker' )
+        || '';
+    my $Direction = $Self->{ParamObject}->GetParam( Param => 'Direction' )
+        || '';
 
     my $CommunicationType = IsStringWithData($Operation) ? 'Provider'  : 'Requester';
     my $ActionType        = IsStringWithData($Operation) ? 'Operation' : 'Invoker';
     my $Action = $Operation || $Invoker;
 
-    # Set mapping direction for display.
-    my $MappingDirection = $Direction eq 'MappingOutbound'
-        ? Translatable('Simple Mapping for Outgoing Data')
-        : Translatable('Simple Mapping for Incoming Data');
+    # set mapping direction for display
+    my $MappingDirection
+        = $Direction eq 'MappingOutbound'
+        ? 'Simple Mapping for Outgoing Data'
+        : 'Simple Mapping for Incoming Data';
 
-    # Get configured Actions.
-    my $ActionsConfig = $Kernel::OM->Get('Kernel::Config')->Get( 'GenericInterface::' . $ActionType . '::Module' );
+    # get configured Actions
+    my $ActionsConfig
+        = $Self->{ConfigObject}->Get( 'GenericInterface::' . $ActionType . '::Module' );
 
-    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-
-    # Check for valid action backend.
+    # check for valid action backend
     if ( !IsHashRefWithData($ActionsConfig) ) {
-        return $LayoutObject->ErrorScreen(
-            Message => $LayoutObject->{LanguageObject}
-                ->Translate( 'Could not get registered configuration for action type %s', $ActionType ),
+        return $Self->{LayoutObject}->ErrorScreen(
+            Message => "Could not get registered configuration for action type $ActionType",
         );
     }
 
-    # Check for WebserviceID.
+    # check for WebserviceID
     if ( !$WebserviceID ) {
-        return $LayoutObject->ErrorScreen(
-            Message => Translatable('Need WebserviceID!'),
-        );
+        return $Self->{LayoutObject}
+            ->ErrorScreen( Message => "Need WebserviceID!", );
     }
 
-    # Get web service object.
-    my $WebserviceObject = $Kernel::OM->Get('Kernel::System::GenericInterface::Webservice');
+    # get webservice configuration
+    my $WebserviceData =
+        $Self->{WebserviceObject}->WebserviceGet( ID => $WebserviceID );
 
-    # Get web service configuration
-    my $WebserviceData = $WebserviceObject->WebserviceGet( ID => $WebserviceID );
-
-    # Check for valid web service configuration.
+    # check for valid webservice configuration
     if ( !IsHashRefWithData($WebserviceData) ) {
-        return $LayoutObject->ErrorScreen(
-            Message =>
-                $LayoutObject->{LanguageObject}->Translate( 'Could not get data for WebserviceID %s', $WebserviceID ),
+        return $Self->{LayoutObject}->ErrorScreen(
+            Message => "Could not get data for WebserviceID $WebserviceID",
         );
     }
 
-    # Get the action type (back-end).
-    my $ActionBackend = $WebserviceData->{Config}->{$CommunicationType}->{$ActionType}->{$Action}->{'Type'};
+    # get the action type (back-end)
+    my $ActionBackend = $WebserviceData->{Config}->{$CommunicationType}->{$ActionType}
+        ->{$Action}->{'Type'};
 
-    # Check for valid action backend.
+    # check for valid action backend
     if ( !$ActionBackend ) {
-        return $LayoutObject->ErrorScreen(
-            Message =>
-                $LayoutObject->{LanguageObject}->Translate( 'Could not get backend for %s %s', $ActionType, $Action ),
+        return $Self->{LayoutObject}->ErrorScreen(
+            Message => "Could not get backend for $ActionType $Action",
         );
     }
 
-    # Get the configuration dialog for the action.
+    # get the configuration dialog for the action
     my $ActionFrontendModule = $ActionsConfig->{$ActionBackend}->{'ConfigDialog'};
 
     my $WebserviceName = $WebserviceData->{Name};
 
-    # -------------------------------------------------------------- #
-    # sub-action Add or Change: load web service and show edit screen
-    # -------------------------------------------------------------- #
+    # ------------------------------------------------------------ #
+    # subaction Change: load webservice and show edit screen
+    # ------------------------------------------------------------ #
     if ( $Self->{Subaction} eq 'Add' || $Self->{Subaction} eq 'Change' ) {
 
-        # Recreate structure for edit.
+        # recreate structure for edit
         my %Mapping;
 
         my $MappingConfig = $WebserviceData->{Config}->{$CommunicationType}->
@@ -113,10 +130,10 @@ sub Run {
         $Mapping{DefaultValueMapTo} = $MappingConfig->{ValueMapDefault}->{MapTo};
         $Mapping{DefaultValueType}  = $MappingConfig->{ValueMapDefault}->{MapType};
 
-        # Add saved values.
+        # add saved values
         my $KeyIndex = 0;
         for my $KeyMapType (qw( KeyMapExact KeyMapRegEx )) {
-            for my $Key ( sort keys %{ $MappingConfig->{$KeyMapType} } ) {
+            for my $Key ( keys %{ $MappingConfig->{$KeyMapType} } ) {
                 $KeyIndex++;
                 my $NewKey = $MappingConfig->{$KeyMapType}->{$Key};
 
@@ -127,24 +144,27 @@ sub Run {
                 my $ValueIndex = 0;
                 for my $ValueMapType (qw( ValueMapExact ValueMapRegEx )) {
                     for my $ValueName (
-                        sort keys %{ $MappingConfig->{ValueMap}->{$NewKey}->{$ValueMapType} }
+                        keys %{ $MappingConfig->{ValueMap}->{$NewKey}->{$ValueMapType} }
                         )
                     {
                         $ValueIndex++;
-                        my $NewVal = $MappingConfig->{ValueMap}->{$NewKey}->{$ValueMapType}->{$ValueName};
+                        my $NewVal
+                            = $MappingConfig->{ValueMap}->{$NewKey}->{$ValueMapType}->{$ValueName},
+
+                            $Mapping{ 'ValueName' . $KeyIndex . '_' . $ValueIndex } = $ValueName;
+                        $Mapping{ 'ValueMapNew' . $KeyIndex . '_' . $ValueIndex } = $NewVal;
+                        $Mapping{ 'ValueMapTypeStrg' . $KeyIndex . '_' . $ValueIndex }
+                            = $ValueMapType;
 
-                        $Mapping{ 'ValueName' . $KeyIndex . '_' . $ValueIndex }        = $ValueName;
-                        $Mapping{ 'ValueMapNew' . $KeyIndex . '_' . $ValueIndex }      = $NewVal;
-                        $Mapping{ 'ValueMapTypeStrg' . $KeyIndex . '_' . $ValueIndex } = $ValueMapType;
                     }
                 }
 
-                # Set value index.
+                # set value index
                 $Mapping{ 'ValueCounter' . $KeyIndex } = $ValueIndex;
             }
         }
 
-        # Set Key index.
+        # set Key index
         $Mapping{'KeyCounter'} = $KeyIndex;
 
         return $Self->_ShowEdit(
@@ -165,16 +185,17 @@ sub Run {
     }
 
     # ------------------------------------------------------------ #
-    # sub-action ChangeAction: write config and return to overview
+    # subaction ChangeAction: write config and return to overview
     # ------------------------------------------------------------ #
     else {
 
-        # Challenge token check for write action.
-        $LayoutObject->ChallengeTokenCheck();
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
 
-        my $GetParam = $Self->_GetParams();
+        # get parameter from web browser
+        my $GetParam = $Self->_GetParams;
 
-        # Ff there is an error return to edit screen
+        # if there is an error return to edit screen
         if ( $GetParam->{Error} ) {
             return $Self->_ShowEdit(
                 %Param,
@@ -195,32 +216,35 @@ sub Run {
 
         my %NewMapping;
 
-        # Set default key.
+        # set default key
         $NewMapping{KeyMapDefault}->{MapType} = $GetParam->{DefaultKeyType};
         $NewMapping{KeyMapDefault}->{MapTo}   = $GetParam->{DefaultKeyMapTo};
 
-        # Set default value.
+        # set default value
         $NewMapping{ValueMapDefault}->{MapType} = $GetParam->{DefaultValueType};
         $NewMapping{ValueMapDefault}->{MapTo}   = $GetParam->{DefaultValueMapTo};
 
         for my $KeyCounter ( 1 .. $GetParam->{KeyCounter} ) {
-            $NewMapping{ $GetParam->{ 'KeyMapTypeStrg' . $KeyCounter } }->{ $GetParam->{ 'KeyName' . $KeyCounter } }
-                = $GetParam->{ 'KeyMapNew' . $KeyCounter };
+            $NewMapping{ $GetParam->{ 'KeyMapTypeStrg' . $KeyCounter } }
+                ->{ $GetParam->{ 'KeyName' . $KeyCounter } }
+                =
+                $GetParam->{ 'KeyMapNew' . $KeyCounter };
 
             for my $ValueCounter ( 1 .. $GetParam->{ 'ValueCounter' . $KeyCounter } ) {
-                $NewMapping{ValueMap}->{ $GetParam->{ 'KeyMapNew' . $KeyCounter } }
-                    ->{ $GetParam->{ 'ValueMapTypeStrg' . $KeyCounter . '_' . $ValueCounter } }
-                    ->{ $GetParam->{ 'ValueName' . $KeyCounter . '_' . $ValueCounter } }
-                    = $GetParam->{ 'ValueMapNew' . $KeyCounter . '_' . $ValueCounter };
+                $NewMapping{ValueMap}->{ $GetParam->{ 'KeyMapNew' . $KeyCounter } }->
+                    { $GetParam->{ 'ValueMapTypeStrg' . $KeyCounter . '_' . $ValueCounter } }->
+                    { $GetParam->{ 'ValueName' . $KeyCounter . '_' . $ValueCounter } } =
+                    $GetParam->{ 'ValueMapNew' . $KeyCounter . '_' . $ValueCounter };
             }
         }
 
-        # Set new mapping.
-        $WebserviceData->{Config}->{$CommunicationType}->{$ActionType}->{$Action}->{$Direction}->{Config}
+        # set new mapping
+        $WebserviceData->{Config}->{$CommunicationType}->{$ActionType}->{$Action}->{$Direction}
+            ->{Config}
             = \%NewMapping;
 
-        # Save configuration and return to edit or overview screen.
-        my $Success = $WebserviceObject->WebserviceUpdate(
+        # otherwise save configuration and return to overview screen
+        my $Success = $Self->{WebserviceObject}->WebserviceUpdate(
             ID      => $WebserviceID,
             Name    => $WebserviceData->{Name},
             Config  => $WebserviceData->{Config},
@@ -228,49 +252,88 @@ sub Run {
             UserID  => $Self->{UserID},
         );
 
-        # Check for successful web service update.
+        # check for successful web service update
         if ( !$Success ) {
-            return $LayoutObject->ErrorScreen(
-                Message => $LayoutObject->{LanguageObject}
-                    ->Translate( 'Could not update configuration data for WebserviceID %s', $WebserviceID ),
+            return $Self->{LayoutObject}->ErrorScreen(
+                Message => "Could not update configuration data for WebserviceID $WebserviceID",
             );
         }
 
-        # If the user would like to continue editing the invoker config, just redirect to the edit screen
-        my $RedirectURL;
-        if (
-            defined $ParamObject->GetParam( Param => 'ContinueAfterSave' )
-            && ( $ParamObject->GetParam( Param => 'ContinueAfterSave' ) eq '1' )
-            )
-        {
+        # save and finish button: go to Webservice.
+        if ( $Self->{ParamObject}->GetParam( Param => 'ReturnToAction' ) ) {
+            my $RedirectURL
+                = "Action=$ActionFrontendModule;Subaction=Change;$ActionType=$Action;"
+                . "WebserviceID=$WebserviceID;";
 
-            $RedirectURL =
-                'Action='
-                . $Self->{Action}
-                . ';Subaction=Change;WebserviceID='
-                . $WebserviceID
-                . ";$ActionType="
-                . $LayoutObject->LinkEncode($Action)
-                . ';Direction='
-                . $Direction
-                . ';';
-        }
-        else {
-
-            # Otherwise return to overview.
-            $RedirectURL =
-                'Action='
-                . $ActionFrontendModule
-                . ';Subaction=Change;'
-                . ";$ActionType="
-                . $LayoutObject->LinkEncode($Action)
-                . ';WebserviceID='
-                . $WebserviceID
-                . ';';
+            return $Self->{LayoutObject}->Redirect(
+                OP => $RedirectURL,
+            );
         }
 
-        return $LayoutObject->Redirect(
-            OP => $RedirectURL,
+        # recreate structure for edit
+        my %Mapping;
+
+        my $MappingConfig = $WebserviceData->{Config}->{$CommunicationType}->
+            {$ActionType}->{$Action}->{$Direction}->{Config};
+
+        $Mapping{DefaultKeyMapTo} = $MappingConfig->{KeyMapDefault}->{MapTo};
+        $Mapping{DefaultKeyType}  = $MappingConfig->{KeyMapDefault}->{MapType};
+
+        $Mapping{DefaultValueMapTo} = $MappingConfig->{ValueMapDefault}->{MapTo};
+        $Mapping{DefaultValueType}  = $MappingConfig->{ValueMapDefault}->{MapType};
+
+        # add saved values
+        my $KeyIndex = 0;
+        for my $KeyMapType (qw( KeyMapExact KeyMapRegEx )) {
+            for my $Key ( keys %{ $MappingConfig->{$KeyMapType} } ) {
+                $KeyIndex++;
+                my $NewKey = $MappingConfig->{$KeyMapType}->{$Key};
+
+                $Mapping{ 'KeyName' . $KeyIndex }        = $Key;
+                $Mapping{ 'KeyMapNew' . $KeyIndex }      = $NewKey;
+                $Mapping{ 'KeyMapTypeStrg' . $KeyIndex } = $KeyMapType;
+
+                my $ValueIndex = 0;
+                for my $ValueMapType (qw( ValueMapExact ValueMapRegEx )) {
+                    for my $ValueName (
+                        keys %{ $MappingConfig->{ValueMap}->{$NewKey}->{$ValueMapType} }
+                        )
+                    {
+                        $ValueIndex++;
+                        my $NewVal
+                            = $MappingConfig->{ValueMap}->{$NewKey}->{$ValueMapType}->{$ValueName},
+
+                            $Mapping{ 'ValueName' . $KeyIndex . '_' . $ValueIndex } = $ValueName;
+                        $Mapping{ 'ValueMapNew' . $KeyIndex . '_' . $ValueIndex } = $NewVal;
+                        $Mapping{ 'ValueMapTypeStrg' . $KeyIndex . '_' . $ValueIndex }
+                            = $ValueMapType;
+
+                    }
+                }
+
+                # set value index
+                $Mapping{ 'ValueCounter' . $KeyIndex } = $ValueIndex;
+            }
+        }
+
+        # set Key index
+        $Mapping{'KeyCounter'} = $KeyIndex;
+
+        # check if stay on mapping screen or redirect to prev screen
+        return $Self->_ShowEdit(
+            %Param,
+            WebserviceID         => $WebserviceID,
+            WebserviceName       => $WebserviceName,
+            WebserviceData       => \%Mapping,
+            Operation            => $Operation,
+            Invoker              => $Invoker,
+            Direction            => $Direction,
+            MappingDirection     => $MappingDirection,
+            CommunicationType    => $CommunicationType,
+            ActionType           => $ActionType,
+            Action               => $Action,
+            ActionFrontendModule => $ActionFrontendModule,
+            Subaction            => 'Change',
         );
     }
 }
@@ -278,13 +341,11 @@ sub Run {
 sub _ShowEdit {
     my ( $Self, %Param ) = @_;
 
-    # Set action for go back button.
+    # set action for go back button
     $Param{LowerCaseActionType} = lc $Param{ActionType};
 
-    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-
-    my $Output = $LayoutObject->Header();
-    $Output .= $LayoutObject->NavigationBar();
+    my $Output = $Self->{LayoutObject}->Header();
+    $Output .= $Self->{LayoutObject}->NavigationBar();
 
     my $MappingConfig = $Param{WebserviceData};
     my %Error;
@@ -304,91 +365,90 @@ sub _ShowEdit {
     $Param{DefaultValueMapTo} = $MappingConfig->{DefaultValueMapTo};
 
     my $DefaultValueType = $MappingConfig->{DefaultValueType} || '';
-    $Param{DefaultValueMapToHidden} = $DefaultValueType ne 'MapTo' ? 'Hidden' : 'Validate_Required';
+    $Param{DefaultValueMapToHidden} =
+        $DefaultValueType ne 'MapTo' ? 'Hidden' : 'Validate_Required';
 
     $Param{DefaultValueMapToError} = $Error{DefaultValueMapTo} || '';
     $Param{DefaultValueTypeError}  = $Error{DefaultValueType}  || '';
 
-    # Select object for keys.
-    $Param{DefaultKeyTypeStrg} = $LayoutObject->BuildSelection(
+    # select object for keys
+    $Param{DefaultKeyTypeStrg} = $Self->{LayoutObject}->BuildSelection(
         Data => [
             {
                 Key   => 'Keep',
-                Value => Translatable('Keep (leave unchanged)'),
+                Value => 'Keep (leave unchanged)',
             },
             {
                 Key   => 'Ignore',
-                Value => Translatable('Ignore (drop key/value pair)'),
+                Value => 'Ignore (drop key/value pair)',
             },
             {
                 Key   => 'MapTo',
-                Value => Translatable('Map to (use provided value as default)'),
+                Value => 'MapTo (use provided value as default)',
             },
         ],
         Name         => 'DefaultKeyType',
-        Class        => 'Modernize DefaultType ' . $Param{DefaultKeyTypeError},
+        Class        => 'DefaultType ' . $Param{DefaultKeyTypeError},
         SelectedID   => $MappingConfig->{DefaultKeyType},
         PossibleNone => 0,
         Translate    => 0,
     );
-    $Param{KeyMapTypeStrg} = $LayoutObject->BuildSelection(
+    $Param{KeyMapTypeStrg} = $Self->{LayoutObject}->BuildSelection(
         Data => [
             {
                 Key   => 'KeyMapExact',
-                Value => Translatable('Exact value(s)'),
+                Value => 'Exact value(s)',
             },
             {
                 Key   => 'KeyMapRegEx',
-                Value => Translatable('Regular expression'),
+                Value => 'Regular expression',
             },
         ],
         Name         => 'KeyMapTypeStrg',
         PossibleNone => 0,
         Translate    => 0,
-        Class        => 'Modernize',
     );
 
-    # Select objects for values.
-    $Param{DefaultValueTypeStrg} = $LayoutObject->BuildSelection(
+    # select objects for values
+    $Param{DefaultValueTypeStrg} = $Self->{LayoutObject}->BuildSelection(
         Data => [
             {
                 Key   => 'Keep',
-                Value => Translatable('Keep (leave unchanged)'),
+                Value => 'Keep (leave unchanged)',
             },
             {
                 Key   => 'Ignore',
-                Value => Translatable('Ignore (drop Value/value pair)'),
+                Value => 'Ignore (drop Value/value pair)',
             },
             {
                 Key   => 'MapTo',
-                Value => Translatable('Map to (use provided value as default)'),
+                Value => 'MapTo (use provided value as default)',
             },
         ],
         Name         => 'DefaultValueType',
-        Class        => 'Modernize DefaultType ' . $Param{DefaultKeyTypeError},
+        Class        => 'DefaultType ' . $Param{DefaultKeyTypeError},
         SelectedID   => $MappingConfig->{DefaultValueType},
         PossibleNone => 0,
         Translate    => 0,
     );
 
-    $Param{ValueMapTypeStrg} = $LayoutObject->BuildSelection(
+    $Param{ValueMapTypeStrg} = $Self->{LayoutObject}->BuildSelection(
         Data => [
             {
                 Key   => 'ValueMapExact',
-                Value => Translatable('Exact value(s)'),
+                Value => 'Exact value(s)',
             },
             {
                 Key   => 'ValueMapRegEx',
-                Value => Translatable('Regular expression'),
+                Value => 'Regular expression',
             },
         ],
         Name         => 'ValueMapTypeStrg',
         PossibleNone => 0,
         Translate    => 0,
-        Class        => 'Modernize',
     );
 
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'KeyTemplate',
         Data => {
             Classes => 'KeyTemplate Hidden',
@@ -397,8 +457,8 @@ sub _ShowEdit {
         },
     );
 
-    # Set value index.
-    $LayoutObject->Block(
+    # set value index
+    $Self->{LayoutObject}->Block(
         Name => 'ValueTemplateRowIndex',
         Data => {
             KeyIndex   => '',
@@ -406,29 +466,29 @@ sub _ShowEdit {
         },
     );
 
-    # Add saved values.
+    # add saved values
     for my $KeyIndex ( 1 .. $MappingConfig->{KeyCounter} ) {
         my $KeyMapTypeStrgError = $Error{ 'KeyMapTypeStrg' . $KeyIndex } || '';
 
-        # Build map type selection.
-        my $KeyMapTypeStrg = $LayoutObject->BuildSelection(
+        # build map type selection
+        my $KeyMapTypeStrg = $Self->{LayoutObject}->BuildSelection(
             Data => [
                 {
                     Key   => 'KeyMapExact',
-                    Value => Translatable('Exact value(s)'),
+                    Value => 'Exact value(s)',
                 },
                 {
                     Key   => 'KeyMapRegEx',
-                    Value => Translatable('Regular expression'),
+                    Value => 'Regular expression',
                 },
             ],
             Name         => 'KeyMapTypeStrg' . $KeyIndex,
             SelectedID   => $MappingConfig->{ 'KeyMapTypeStrg' . $KeyIndex },
-            Class        => 'Modernize Validate_Required ' . $KeyMapTypeStrgError,
+            Class        => 'Validate_Required ' . $KeyMapTypeStrgError,
             PossibleNone => 0,
             Translate    => 0,
         );
-        $LayoutObject->Block(
+        $Self->{LayoutObject}->Block(
             Name => 'KeyTemplate',
             Data => {
                 KeyIndex       => $KeyIndex,
@@ -441,42 +501,46 @@ sub _ShowEdit {
         );
 
         for my $ValueIndex ( 1 .. $MappingConfig->{ 'ValueCounter' . $KeyIndex } ) {
-            my $ValueMapTypeStrgError = $Error{ 'ValueMapTypeStrg' . $KeyIndex . '_' . $ValueIndex } || '';
-            my $ValueMapTypeStrg      = $LayoutObject->BuildSelection(
+            my $ValueMapTypeStrgError = $Error{ 'ValueMapTypeStrg' . $KeyIndex . '_' . $ValueIndex }
+                || '';
+            my $ValueMapTypeStrg = $Self->{LayoutObject}->BuildSelection(
                 Data => [
                     {
                         Key   => 'ValueMapExact',
-                        Value => Translatable('Exact value(s)'),
+                        Value => 'Exact value(s)',
                     },
                     {
                         Key   => 'ValueMapRegEx',
-                        Value => Translatable('Regular expression'),
+                        Value => 'Regular expression',
                     },
                 ],
-                Name         => 'ValueMapTypeStrg' . $KeyIndex . '_' . $ValueIndex,
-                SelectedID   => $MappingConfig->{ 'ValueMapTypeStrg' . $KeyIndex . '_' . $ValueIndex },
-                Class        => 'Modernize Validate_Required ' . $ValueMapTypeStrgError,
+                Name => 'ValueMapTypeStrg' . $KeyIndex . '_' . $ValueIndex,
+                SelectedID =>
+                    $MappingConfig->{ 'ValueMapTypeStrg' . $KeyIndex . '_' . $ValueIndex },
+                Class        => 'Validate_Required ' . $ValueMapTypeStrgError,
                 PossibleNone => 0,
                 Translate    => 0,
             );
 
-            # Build map type selection.
-            $LayoutObject->Block(
+            # build map type selection
+            $Self->{LayoutObject}->Block(
                 Name => 'ValueTemplateRow',
                 Data => {
-                    KeyIndex         => $KeyIndex,
-                    ValueIndex       => $ValueIndex,
-                    ValueName        => $MappingConfig->{ 'ValueName' . $KeyIndex . '_' . $ValueIndex },
-                    ValueNameError   => $Error{ 'ValueName' . $KeyIndex . '_' . $ValueIndex } || '',
-                    ValueMapNew      => $MappingConfig->{ 'ValueMapNew' . $KeyIndex . '_' . $ValueIndex },
-                    ValueMapNewError => $Error{ 'ValueMapNew' . $KeyIndex . '_' . $ValueIndex } || '',
+                    KeyIndex   => $KeyIndex,
+                    ValueIndex => $ValueIndex,
+                    ValueName  => $MappingConfig->{ 'ValueName' . $KeyIndex . '_' . $ValueIndex },
+                    ValueNameError => $Error{ 'ValueName' . $KeyIndex . '_' . $ValueIndex } || '',
+                    ValueMapNew =>
+                        $MappingConfig->{ 'ValueMapNew' . $KeyIndex . '_' . $ValueIndex },
+                    ValueMapNewError => $Error{ 'ValueMapNew' . $KeyIndex . '_' . $ValueIndex }
+                        || '',
                     ValueMapTypeStrg => $ValueMapTypeStrg,
                 },
             );
         }
 
-        # Set index value.
-        $LayoutObject->Block(
+        # set index value
+        $Self->{LayoutObject}->Block(
             Name => 'ValueTemplateRowIndex',
             Data => {
                 KeyIndex   => $KeyIndex,
@@ -486,34 +550,25 @@ sub _ShowEdit {
 
     }
 
-    # Send data to JS.
-    $LayoutObject->AddJSData(
-        Key   => 'MappingSimple',
-        Value => {
-            WebServiceID  => $Param{WebserviceID},
-            DeletedString => $Param{DeletedString},
-        },
-    );
-
-    # Set key index.
-    $LayoutObject->Block(
+    # set key index
+    $Self->{LayoutObject}->Block(
         Name => 'KeyCounter',
         Data => {
             KeyIndex => $MappingConfig->{KeyCounter} || 0,
         },
     );
 
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'ValueTemplate',
         Data => { %Param, },
     );
 
-    $Output .= $LayoutObject->Output(
+    $Output .= $Self->{LayoutObject}->Output(
         TemplateFile => 'AdminGenericInterfaceMappingSimple',
         Data         => { %Param, },
     );
 
-    $Output .= $LayoutObject->Footer();
+    $Output .= $Self->{LayoutObject}->Footer();
     return $Output;
 }
 
@@ -522,84 +577,69 @@ sub _GetParams {
 
     my $GetParam;
 
-    my $ParamObject = $Kernel::OM->Get('Kernel::System::Web::Request');
-
-    # Get parameters from web browser.
-    PARAM_NAME:
+    # get parameters from web browser
     for my $ParamName (
         qw(
         DefaultKeyType DefaultKeyMapTo DefaultValueType DefaultValueMapTo
         )
         )
     {
-        $GetParam->{$ParamName} = $ParamObject->GetParam( Param => $ParamName ) || '';
+        $GetParam->{$ParamName} =
+            $Self->{ParamObject}->GetParam( Param => $ParamName ) || '';
         if ( $GetParam->{$ParamName} eq '' ) {
             if ( $ParamName =~ /(DefaultKeyMapTo|DefaultValueMapTo)/i ) {
                 my $ParamPart = substr( $ParamName, 0, -5 );
-                if ( $ParamObject->GetParam( Param => $ParamPart . 'Type' ) ne 'MapTo' ) {
-                    next PARAM_NAME;
+                if ( $Self->{ParamObject}->GetParam( Param => $ParamPart . 'Type' ) ne 'MapTo' ) {
+                    next;
                 }
             }
             $GetParam->{Error}->{$ParamName} = 'ServerError';
         }
     }
 
-    # Get key counter param (it can be zero if just defaults where defined).
+    # get key counter param (it can be zero if just defaults where defined)
     $GetParam->{KeyCounter} =
-        $ParamObject->GetParam( Param => 'KeyCounter' ) || 0;
+        $Self->{ParamObject}->GetParam( Param => 'KeyCounter' ) || 0;
 
-    # Get params for keys.
+    # get params for keys
     my $KeyIndex = 0;
-    KEYCOUNTER:
     for my $KeyCounter ( 1 .. $GetParam->{KeyCounter} ) {
-        next KEYCOUNTER if !$ParamObject->GetParam( Param => 'KeyIndex' . $KeyCounter );
-
+        next if !$Self->{ParamObject}->GetParam( Param => 'KeyIndex' . $KeyCounter );
         $KeyIndex++;
-        KEY_ITEM:
         for my $KeyItem (qw(KeyMapTypeStrg KeyName KeyMapNew ValueCounter)) {
-            my $KeyAux = $ParamObject->GetParam( Param => $KeyItem . $KeyCounter ) // '';
+            my $KeyAux = $Self->{ParamObject}->GetParam( Param => $KeyItem . $KeyCounter ) || '';
             $GetParam->{ $KeyItem . $KeyIndex } = $KeyAux;
-
             if ( $KeyItem eq 'ValueCounter' && $KeyAux eq '' ) {
                 $GetParam->{ $KeyItem . $KeyIndex } = 0;
-                next KEY_ITEM;
-            }
-
-            if ( $KeyAux eq '' ) {
-                $GetParam->{Error}->{ $KeyItem . $KeyIndex } = 'ServerError';
+                next;
             }
+            $GetParam->{Error}->{ $KeyItem . $KeyIndex } = 'ServerError'
+                if $KeyAux eq '';
         }
 
-        # Get params for values.
+        # get params for values
         my $ValueIndex = 0;
-        COUNTER:
         for my $ValueCounter ( 1 .. $GetParam->{ 'ValueCounter' . $KeyIndex } ) {
             my $Suffix = $KeyCounter . '_' . $ValueCounter;
-
-            if ( $ParamObject->GetParam( Param => 'ValueName' . $Suffix ) eq $Self->{DeletedString} ) {
-                next COUNTER;
-            }
-
+            next
+                if $Self->{ParamObject}->GetParam( Param => 'ValueName' . $Suffix ) eq
+                $Self->{DeletedString};
             $ValueIndex++;
-
             for my $ValueItem (qw(ValueMapTypeStrg ValueName ValueMapNew)) {
-                my $ValAux = $ParamObject->GetParam( Param => $ValueItem . $Suffix ) // '';
+                my $ValAux = $Self->{ParamObject}->GetParam( Param => $ValueItem . $Suffix ) || '';
                 $GetParam->{ $ValueItem . $KeyIndex . '_' . $ValueIndex } = $ValAux;
-
-                if ( $ValAux eq '' ) {
-                    $GetParam->{Error}->{ $ValueItem . $KeyIndex . '_' . $ValueIndex } = 'ServerError';
-                }
+                $GetParam->{Error}->{ $ValueItem . $KeyIndex . '_' . $ValueIndex } = 'ServerError'
+                    if $ValAux eq '';
             }
         }
 
-        # Set new value index.
+        # set new value index
         $GetParam->{ 'ValueCounter' . $KeyIndex } = $ValueIndex;
     }
 
-    # Set new key index.
+    # set new key index
     $GetParam->{KeyCounter} = $KeyIndex;
 
     return $GetParam;
 }
-
 1;
