@@ -1,6 +1,8 @@
 # --
 # Kernel/Output/HTML/DashboardMOTD.pm
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# --
+# $Id: DashboardMOTD.pm,v 1.1 2009-09-21 13:15:50 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,11 +14,6 @@ package Kernel::Output::HTML::DashboardMOTD;
 use strict;
 use warnings;
 
-# prevent 'Used once' warning
-use Kernel::System::ObjectManager;
-
-our $ObjectManagerDisabled = 1;
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -24,9 +21,12 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
-    # get needed parameters
-    for my $Needed (qw(Config Name UserID)) {
-        die "Got no $Needed!" if ( !$Self->{$Needed} );
+    # get needed objects
+    for (
+        qw(Config Name ConfigObject LogObject DBObject LayoutObject ParamObject TicketObject UserID)
+        )
+    {
+        die "Got no $_!" if ( !$Self->{$_} );
     }
 
     return $Self;
@@ -49,7 +49,7 @@ sub Config {
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    my $Content = $Kernel::OM->Get('Kernel::Output::HTML::Layout')->Output(
+    my $Content = $Self->{LayoutObject}->Output(
         TemplateFile => 'Motd',
         Data         => {
             %{ $Self->{Config} },
