@@ -1,6 +1,6 @@
 # --
 # Kernel/System/DynamicField/Backend/Checkbox.pm - Delegate for DynamicField Checkbox backend
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # $Id: Checkbox.pm,v 1.52.2.2 2012-06-19 23:53:27 cr Exp $
 # --
@@ -206,14 +206,14 @@ sub EditFieldRender {
     if ( defined $FieldValue && IsHashRefWithData($FieldValue) ) {
         if (
             !defined $FieldValue->{FieldValue} &&
-            defined $FieldValue->{UsedValue} && $FieldValue->{UsedValue} eq '1'
+            defined $FieldValue->{UsedValue}   && $FieldValue->{UsedValue} eq '1'
             )
         {
             $Value = '0';
         }
         elsif (
             defined $FieldValue->{FieldValue} && $FieldValue->{FieldValue} eq '1' &&
-            defined $FieldValue->{UsedValue}  && $FieldValue->{UsedValue}  eq '1'
+            defined $FieldValue->{UsedValue} && $FieldValue->{UsedValue} eq '1'
             )
         {
             $Value = '1';
@@ -454,7 +454,7 @@ sub SearchFieldRender {
     my @DefaultValue;
 
     if ( defined $Param{DefaultValue} ) {
-        my @DefaultValue = split /;/, $Param{DefaultValue};
+        @DefaultValue = split /;/, $Param{DefaultValue};
     }
 
     # set the field value
@@ -568,7 +568,9 @@ sub SearchFieldParameterBuild {
                     :               '';
 
                 # translate the value
-                $DisplayItem = $Param{LayoutObject}->{LanguageObject}->Get($DisplayItem);
+                if ( defined $Param{LayoutObject} ) {
+                    $DisplayItem = $Param{LayoutObject}->{LanguageObject}->Get($DisplayItem);
+                }
 
                 push @DisplayItemList, $DisplayItem;
 
@@ -592,7 +594,9 @@ sub SearchFieldParameterBuild {
                 :                '';
 
             # translate the value
-            $DisplayValue = $Param{LayoutObject}->{LanguageObject}->Get($DisplayValue);
+            if ( defined $Param{LayoutObject} ) {
+                $DisplayValue = $Param{LayoutObject}->{LanguageObject}->Get($DisplayValue);
+            }
         }
 
         # set the correct value for "unchecked" (-1) search options
@@ -735,6 +739,9 @@ sub ObjectMatch {
 
     my $FieldName = 'DynamicField_' . $Param{DynamicFieldConfig}->{Name};
 
+    # return false if field is not defined
+    return 0 if ( !defined $Param{ObjectAttributes}->{$FieldName} );
+
     # return false if not match
     if ( $Param{ObjectAttributes}->{$FieldName} ne $Param{Value} ) {
         return 0;
