@@ -1,8 +1,8 @@
 # --
 # Kernel/System/DynamicField/Backend/TextArea.pm - Delegate for DynamicField TextArea backend
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
-# $Id: TextArea.pm,v 1.48 2012/03/30 16:16:39 cr Exp $
+# $Id: TextArea.pm,v 1.48.2.5 2012-11-14 22:14:54 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -19,7 +19,7 @@ use Kernel::System::DynamicFieldValue;
 use Kernel::System::DynamicField::Backend::BackendCommon;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.48 $) [1];
+$VERSION = qw($Revision: 1.48.2.5 $) [1];
 
 =head1 NAME
 
@@ -62,6 +62,10 @@ sub new {
     $Self->{BackendCommonObject}
         = Kernel::System::DynamicField::Backend::BackendCommon->new( %{$Self} );
 
+    # set the maximum lenght for the textarea fields to still be a searchable field in some
+    # databases
+    $Self->{MaxLength} = 3800;
+
     return $Self;
 }
 
@@ -201,10 +205,12 @@ sub EditFieldRender {
     }
 
     # set the rows number
-    my $RowsNumber = ( defined $FieldConfig->{Rows} ? $FieldConfig->{Rows} : '7' );
+    my $RowsNumber
+        = defined $FieldConfig->{Rows} && $FieldConfig->{Rows} ? $FieldConfig->{Rows} : '7';
 
     # set the cols number
-    my $ColsNumber = ( defined $FieldConfig->{Cols} ? $FieldConfig->{Cols} : '42' );
+    my $ColsNumber
+        = defined $FieldConfig->{Cols} && $FieldConfig->{Cols} ? $FieldConfig->{Cols} : '42';
 
     # check and set class if necessary
     my $FieldClass = 'DynamicFieldTextArea';
@@ -218,18 +224,41 @@ sub EditFieldRender {
     # set error css class
     $FieldClass .= ' ServerError' if $Param{ServerError};
 
+    # set validation class for maximum characters
+    $FieldClass .= ' Validate_MaxLength';
+
+    # create field HTML
+    # the XHTML definition does not support maxlenght attribute for a textarea field, therefore
+    # is nedded to be set by JS code (otherwise wc3 validator will complaint about it)
+    # notice that some browsers count new lines \n\r as only 1 character in this cases the
+    # validation framework might rise an error while the user is still capable to enter text in the
+    # textarea, otherwise the maxlenght property will prevent to enter more text than the maximum
     my $HTMLString = <<"EOF";
 <textarea class="$FieldClass" id="$FieldName" name="$FieldName" title="$FieldLabel" rows="$RowsNumber" cols="$ColsNumber" >$Value</textarea>
+<!--dtl:js_on_document_complete-->
+<script type="text/javascript">//<![CDATA[
+  \$('#$FieldName').attr('maxlength','$Self->{MaxLength}');
+//]]></script>
+<!--dtl:js_on_document_complete-->
 EOF
 
-    if ( $Param{Mandatory} ) {
-        my $DivID = $FieldName . 'Error';
+    # for client side validation
+    my $DivID = $FieldName . 'Error';
 
-        # for client side validation
+    if ( $Param{Mandatory} ) {
         $HTMLString .= <<"EOF";
     <div id="$DivID" class="TooltipErrorMessage">
         <p>
-            \$Text{"This field is required."}
+            \$Text{"This field is required or The field content is too long! Maximum size is $Self->{MaxLength} characters."}
+        </p>
+    </div>
+EOF
+    }
+    else {
+        $HTMLString .= <<"EOF";
+    <div id="$DivID" class="TooltipErrorMessage">
+        <p>
+            \$Text{"The field content is too long! Maximum size is $Self->{MaxLength} characters."}
         </p>
     </div>
 EOF
@@ -312,6 +341,12 @@ sub EditFieldValueValidate {
         $ServerError = 1;
     }
 
+    if ( length $Value > $Self->{MaxLength} ) {
+        $ServerError = 1;
+        $ErrorMessage
+            = "The field content is too long! Maximum size is $Self->{MaxLength} characters.";
+    }
+
     # create resulting structure
     my $Result = {
         ServerError  => $ServerError,
@@ -394,6 +429,11 @@ sub SearchFieldRender {
         $Value = $FieldValue;
     }
 
+    # check if value is an arrayref (GenericAgent Jobs and NotificationEvents)
+    if ( IsArrayRefWithData($Value) ) {
+        $Value = @{$Value}[0];
+    }
+
     # check and set class if necessary
     my $FieldClass = 'DynamicFieldText';
 
@@ -577,6 +617,9 @@ sub ObjectMatch {
 
     my $FieldName = 'DynamicField_' . $Param{DynamicFieldConfig}->{Name};
 
+    # return false if field is not defined
+    return 0 if ( !defined $Param{ObjectAttributes}->{$FieldName} );
+
     # return false if not match
     if ( $Param{ObjectAttributes}->{$FieldName} ne $Param{Value} ) {
         return 0;
