@@ -1,9 +1,12 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/System/EmailParser.pm - the global email parser module
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# --
+# $Id: EmailParser.pm,v 1.107.2.1 2012-11-29 12:42:28 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::EmailParser;
@@ -11,6 +14,8 @@ package Kernel::System::EmailParser;
 use strict;
 use warnings;
 
+use Kernel::System::HTMLUtils;
+
 use Mail::Internet;
 use MIME::Parser;
 use MIME::QuotedPrint;
@@ -18,32 +23,73 @@ use MIME::Base64;
 use MIME::Words qw(:all);
 use Mail::Address;
 
-our $ObjectManagerDisabled = 1;
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.107.2.1 $) [1];
 
 =head1 NAME
 
-Kernel::System::EmailParser - parse and encode an email
+Kernel::System::EmailParser - parse and encode a email
 
-=head1 DESCRIPTION
+=head1 SYNOPSIS
 
-A module to parse and encode an email.
+A module to parse and encode a email.
 
 =head1 PUBLIC INTERFACE
 
-=head2 new()
+=over 4
 
-create an object. Do not use it directly, instead use:
+=cut
 
+=item new()
+
+create an object
+
+    use Kernel::Config;
+    use Kernel::System::Encode;
+    use Kernel::System::Log;
     use Kernel::System::EmailParser;
 
+    # as array ref
+
+    my $ConfigObject = Kernel::Config->new();
+    my $EncodeObject = Kernel::System::Encode->new(
+        ConfigObject => $ConfigObject,
+    );
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+    );
+    my $ParserObject = Kernel::System::EmailParser->new(
+        ConfigObject => $ConfigObject,
+        LogObject    => $LogObject,
+        EncodeObject => $EncodeObject,
+        Email        => \@ArrayOfEmail,
+        Debug        => 0,
+    );
+
+    # as scalar ref
+    my $ParserObject = Kernel::System::EmailParser->new(
+        ConfigObject => $ConfigObject,
+        LogObject    => $LogObject,
+        EncodeObject => $EncodeObject,
+        Email        => \$ScalarOfEmail,
+        Debug        => 0,
+    );
+
     # as string (takes more memory!)
     my $ParserObject = Kernel::System::EmailParser->new(
+        ConfigObject => $ConfigObject,
+        LogObject    => $LogObject,
+        EncodeObject => $EncodeObject,
         Email        => $EmailString,
         Debug        => 0,
     );
 
     # as stand alone mode, without parsing emails
     my $ParserObject = Kernel::System::EmailParser->new(
+        ConfigObject => $ConfigObject,
+        LogObject    => $LogObject,
+        EncodeObject => $EncodeObject,
         Mode         => 'Standalone',
         Debug        => 0,
     );
@@ -60,6 +106,13 @@ sub new {
     # get debug level from parent
     $Self->{Debug} = $Param{Debug} || 0;
 
+    # check needed objects
+    for (qw(LogObject ConfigObject EncodeObject)) {
+        $Self->{$_} = $Param{$_} || die "Got no $_!";
+    }
+
+    $Self->{HTMLUtilsObject} = Kernel::System::HTMLUtils->new(%Param);
+
     if ( $Param{Mode} && $Param{Mode} eq 'Standalone' ) {
         return $Self;
     }
@@ -90,8 +143,6 @@ sub new {
             $Param{Email} = \@Content;
         }
 
-        $Self->{OriginalEmail} = join( '', @{ $Param{Email} } );
-
         # create Mail::Internet object
         $Self->{Email} = Mail::Internet->new( $Param{Email} );
 
@@ -107,9 +158,8 @@ sub new {
         $Self->{ParserParts} = $Parser->parse_data( $Self->{Email}->as_string() );
     }
     else {
-        $Self->{ParserParts}  = $Param{Entity};
-        $Self->{HeaderObject} = $Param{Entity}->head();
-        $Self->{EntityMode}   = 1;
+        $Self->{ParserParts} = $Param{Entity};
+        $Self->{EntityMode}  = 1;
     }
 
     # get NoHTMLChecks param
@@ -123,7 +173,7 @@ sub new {
     return $Self;
 }
 
-=head2 GetPlainEmail()
+=item GetPlainEmail()
 
 To get a email as a string back (plain email).
 
@@ -134,10 +184,10 @@ To get a email as a string back (plain email).
 sub GetPlainEmail {
     my $Self = shift;
 
-    return $Self->{OriginalEmail} || $Self->{Email}->as_string();
+    return $Self->{Email}->as_string();
 }
 
-=head2 GetParam()
+=item GetParam()
 
 To get a header (e. g. Subject, To, ContentType, ...) of an email
 (mime is already done!).
@@ -151,51 +201,56 @@ sub GetParam {
 
     my $What = $Param{WHAT} || return;
 
-    if ( !$Self->{HeaderObject} ) {
-
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => 'HeaderObject is needed!',
-        );
-        return;
-    }
-
     $Self->{HeaderObject}->unfold();
     $Self->{HeaderObject}->combine($What);
     my $Line = $Self->{HeaderObject}->get($What) || '';
     chomp($Line);
-    my $ReturnLine;
+    my $ReturnLine = '';
+    my %Remember;
+    for my $Array ( decode_mimewords($Line) ) {
+        for ( @{$Array} ) {
 
-    # We need to split address lists before decoding; see "6.2. Display of 'encoded-word's"
-    # in RFC 2047. Mail::Address routines will quote stuff if necessary (i.e. comma
-    # or semicolon found in phrase).
-    if ( $What =~ /^(From|To|Cc)/ ) {
-        for my $Address ( Mail::Address->parse($Line) ) {
-            $Address->phrase( $Self->_DecodeString( String => $Address->phrase() ) );
-            $Address->address( $Self->_DecodeString( String => $Address->address() ) );
-            $Address->comment( $Self->_DecodeString( String => $Address->comment() ) );
-            $ReturnLine .= ', ' if $ReturnLine;
-            $ReturnLine .= $Address->format();
+            # I don't know, but decode_mimewords() returns each mime
+            # word two times! Remember to the old one. :-(
+            if ( !$Remember{ $Array->[0] } ) {
+                if ( $Array->[0] && $Array->[1] ) {
+                    $Remember{ $Array->[0] } = 1;
+                }
+
+                # Workaround for OE problem:
+                # If a header contains =?iso-8859-1?Q?Fr=F6hlich=2C_Roman?=
+                # which is decoded ->Fröhlich, Roman<- which gets an problem
+                # because this means two email addresses. We add " at
+                # the start and at the end of this types of words mime.
+                if ( $What =~ /^(From|To|Cc)/ && $Array->[1] ) {
+                    if ( $Array->[0] !~ /^("|')/ && $Array->[0] =~ /,/ ) {
+                        $Array->[0] = '"' . $Array->[0] . '"';
+                        $Remember{ $Array->[0] } = 1;
+                    }
+                }
+                $ReturnLine .= $Self->{EncodeObject}->Convert2CharsetInternal(
+                    Text  => $Array->[0],
+                    From  => $Array->[1] || $Self->GetCharset() || 'us-ascii',
+                    Check => 1,
+                );
+            }
+            else {
+                $Remember{ $Array->[0] } = undef;
+            }
         }
     }
-    else {
-        $ReturnLine = $Self->_DecodeString( String => $Line );
-    }
-
-    $ReturnLine //= '';
 
     # debug
     if ( $Self->{Debug} > 1 ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'debug',
             Message  => "Get: $What; ReturnLine: $ReturnLine; OrigLine: $Line",
         );
     }
-
     return $ReturnLine;
 }
 
-=head2 GetEmailAddress()
+=item GetEmailAddress()
 
 To get the senders email address back.
 
@@ -209,7 +264,7 @@ sub GetEmailAddress {
     my ( $Self, %Param ) = @_;
 
     my $Email = '';
-    for my $EmailSplit ( $Self->_MailAddressParse( Email => $Param{Email} ) ) {
+    for my $EmailSplit ( Mail::Address->parse( $Param{Email} ) ) {
         $Email = $EmailSplit->address();
     }
 
@@ -220,9 +275,9 @@ sub GetEmailAddress {
     return $Email;
 }
 
-=head2 GetRealname()
+=item GetRealname()
 
-to get the sender's C<RealName>.
+To get the senders realname back.
 
     my $Realname = $ParserObject->GetRealname(
         Email => 'Juergen Weber <juergen.qeber@air.com>',
@@ -245,14 +300,13 @@ sub GetRealname {
     }
 
     # fallback of Mail::Address
-    for my $EmailSplit ( $Self->_MailAddressParse( Email => $Param{Email} ) ) {
-        $Realname = $EmailSplit->phrase();
+    for my $EmailSplit ( Mail::Address->parse( $Param{Email} ) ) {
+        $Realname = $EmailSplit->name();
     }
-
     return $Realname;
 }
 
-=head2 SplitAddressLine()
+=item SplitAddressLine()
 
 To get an array of email addresses of an To, Cc or Bcc line back.
 
@@ -268,20 +322,19 @@ sub SplitAddressLine {
     my ( $Self, %Param ) = @_;
 
     my @GetParam;
-    for my $Line ( $Self->_MailAddressParse( Email => $Param{Line} ) ) {
+    for my $Line ( Mail::Address->parse( $Param{Line} ) ) {
         push @GetParam, $Line->format();
     }
-
     return @GetParam;
 }
 
-=head2 GetContentType()
+=item GetContentType()
 
 Returns the message body (or from the first attachment) "ContentType" header.
 
     my $ContentType = $ParserObject->GetContentType();
 
-    (e. g. 'text/plain; charset="iso-8859-1"')
+(e. g. 'text/plain; charset="iso-8859-1"')
 
 =cut
 
@@ -293,31 +346,13 @@ sub GetContentType {
     return $Self->GetParam( WHAT => 'Content-Type' ) || 'text/plain';
 }
 
-=head2 GetContentDisposition()
-
-Returns the message body (or from the first attachment) "ContentDisposition" header.
-
-    my $ContentDisposition = $ParserObject->GetContentDisposition();
-
-    (e. g. 'Content-Disposition: attachment; filename="test-123"')
-
-=cut
-
-sub GetContentDisposition {
-    my $Self = shift;
-
-    return $Self->{ContentDisposition} if $Self->{ContentDisposition};
-
-    return $Self->GetParam( WHAT => 'Content-Disposition' );
-}
-
-=head2 GetCharset()
+=item GetCharset()
 
 Returns the message body (or from the first attachment) "charset".
 
     my $Charset = $ParserObject->GetCharset();
 
-    (e. g. iso-8859-1, utf-8, ...)
+(e. g. iso-8859-1, utf-8, ...)
 
 =cut
 
@@ -329,7 +364,7 @@ sub GetCharset {
 
         # debug
         if ( $Self->{Debug} > 0 ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $Self->{LogObject}->Log(
                 Priority => 'debug',
                 Message  => "Got charset from mime body: $Self->{Charset}",
             );
@@ -337,15 +372,6 @@ sub GetCharset {
         return $Self->{Charset};
     }
 
-    if ( !$Self->{HeaderObject} ) {
-
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => 'HeaderObject is needed!',
-        );
-        return;
-    }
-
     # find charset
     $Self->{HeaderObject}->unfold();
     my $Line = $Self->{HeaderObject}->get('Content-Type') || '';
@@ -359,14 +385,14 @@ sub GetCharset {
 
         # debug
         if ( $Self->{Debug} > 0 ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $Self->{LogObject}->Log(
                 Priority => 'debug',
                 Message =>
                     "Got no charset from email body because of ContentType ($Data{ContentType})!",
             );
         }
 
-        # remember charset
+        # remember to charset
         $Self->{Charset} = '';
 
         # return charset
@@ -378,13 +404,13 @@ sub GetCharset {
 
         # debug
         if ( $Self->{Debug} > 0 ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $Self->{LogObject}->Log(
                 Priority => 'debug',
                 Message  => "Got charset from email body: $Data{Charset}",
             );
         }
 
-        # remember charset
+        # remember to charset
         $Self->{Charset} = $Data{Charset};
 
         # return charset
@@ -396,20 +422,20 @@ sub GetCharset {
 
     # debug
     if ( $Self->{Debug} > 0 ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'debug',
             Message  => 'Got no charset from email body! Take iso-8859-1!',
         );
     }
 
-    # remember charset
+    # remember to charset
     $Self->{Charset} = 'ISO-8859-1';
 
     # return charset
     return 'ISO-8859-1';
 }
 
-=head2 GetReturnContentType()
+=item GetReturnContentType()
 
 Returns the new message body (or from the first attachment) "ContentType" header
 (maybe the message is converted to utf-8).
@@ -428,7 +454,7 @@ sub GetReturnContentType {
 
     # debug
     if ( $Self->{Debug} > 0 ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'debug',
             Message  => "Changed ContentType from '"
                 . $Self->GetContentType()
@@ -438,7 +464,7 @@ sub GetReturnContentType {
     return $ContentType;
 }
 
-=head2 GetReturnCharset()
+=item GetReturnCharset()
 
 Returns the charset of the new message body "Charset"
 (maybe the message is converted to utf-8).
@@ -455,7 +481,7 @@ sub GetReturnCharset {
     return 'utf-8';
 }
 
-=head2 GetMessageBody()
+=item GetMessageBody()
 
 Returns the message body (or from the first attachment) from the email.
 
@@ -467,15 +493,12 @@ sub GetMessageBody {
     my ( $Self, %Param ) = @_;
 
     # check if message body is already there
-    return $Self->{MessageBody} if defined $Self->{MessageBody};
-
-    # get encode object
-    my $EncodeObject = $Kernel::OM->Get('Kernel::System::Encode');
+    return $Self->{MessageBody} if $Self->{MessageBody};
 
     if ( !$Self->{EntityMode} && $Self->{ParserParts}->parts() == 0 ) {
         $Self->{MimeEmail} = 0;
         if ( $Self->{Debug} > 0 ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $Self->{LogObject}->Log(
                 Priority => 'debug',
                 Message  => 'It\'s a plain (not mime) email!',
             );
@@ -487,14 +510,14 @@ sub GetMessageBody {
             $BodyStrg = MIME::QuotedPrint::decode($BodyStrg);
         }
 
-        # base64 decode
+        # base 64 encode
         elsif ( $Self->GetParam( WHAT => 'Content-Transfer-Encoding' ) =~ /base64/i ) {
             $BodyStrg = decode_base64($BodyStrg);
         }
 
         # charset decode
         if ( $Self->GetCharset() ) {
-            $Self->{MessageBody} = $EncodeObject->Convert2CharsetInternal(
+            $Self->{MessageBody} = $Self->{EncodeObject}->Convert2CharsetInternal(
                 Text  => $BodyStrg,
                 From  => $Self->GetCharset(),
                 Check => 1,
@@ -513,22 +536,20 @@ sub GetMessageBody {
     else {
         $Self->{MimeEmail} = 1;
         if ( $Self->{Debug} > 0 ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $Self->{LogObject}->Log(
                 Priority => 'debug',
                 Message  => 'It\'s a mime email!',
             );
         }
 
-        # Check if there is a valid attachment there, if yes, return
-        #   the first attachment (normally text/plain) as message body.
-        # For multipart/mixed emails, PartsAttachments() will concatenate subsequent
-        #   body MIME parts into just one attachment.
+        # check if there is a valid attachment there, if yes, return
+        # first attachment (normally text/plain) as message body
         my @Attachments = $Self->GetAttachments();
         if ( @Attachments > 0 ) {
             $Self->{Charset}     = $Attachments[0]->{Charset};
             $Self->{ContentType} = $Attachments[0]->{ContentType};
             if ( $Self->{Debug} > 0 ) {
-                $Kernel::OM->Get('Kernel::System::Log')->Log(
+                $Self->{LogObject}->Log(
                     Priority => 'debug',
                     Message  => "First attachment ContentType: $Self->{ContentType}",
                 );
@@ -541,7 +562,7 @@ sub GetMessageBody {
 
             # check if charset exists
             if ( $Self->GetCharset() ) {
-                $Self->{MessageBody} = $EncodeObject->Convert2CharsetInternal(
+                $Self->{MessageBody} = $Self->{EncodeObject}->Convert2CharsetInternal(
                     Text  => $Attachments[0]->{Content},
                     From  => $Self->GetCharset(),
                     Check => 1,
@@ -553,7 +574,7 @@ sub GetMessageBody {
                 $Self->{MessageBody} = '- no text message => see attachment -';
             }
 
-            # check if it's a html-only email (store it as attachment and add text/plain)
+            # check it it's a html-only email (store it as attachment and add text/plain)
             $Self->CheckMessageBody();
 
             # return message body
@@ -561,7 +582,7 @@ sub GetMessageBody {
         }
         else {
             if ( $Self->{Debug} > 0 ) {
-                $Kernel::OM->Get('Kernel::System::Log')->Log(
+                $Self->{LogObject}->Log(
                     Priority => 'debug',
                     Message =>
                         'No attachments returned from GetAttachments(), just an empty attachment!?',
@@ -574,11 +595,10 @@ sub GetMessageBody {
             return '-';
         }
     }
-
     return;
 }
 
-=head2 GetAttachments()
+=item GetAttachments()
 
 Returns an array of the email attachments.
 
@@ -593,7 +613,6 @@ Returns an array of the email attachments.
         # optional
         print $Attachment->{ContentID};
         print $Attachment->{ContentAlternative};
-        print $Attachment->{ContentMixed};
     }
 
 =cut
@@ -604,13 +623,13 @@ sub GetAttachments {
     # return if it's no mime email
     return if !$Self->{MimeEmail};
 
-    # return if it is already parsed
+    # return if it got already parsed
     return @{ $Self->{Attachments} } if $Self->{Attachments};
 
     # parse email
     $Self->PartsAttachments( Part => $Self->{ParserParts} );
 
-    # return if no attachments are found
+    # return if no attachments got found
     return if !$Self->{Attachments};
 
     # return attachments
@@ -625,20 +644,17 @@ sub PartsAttachments {
     my $PartCounter        = $Param{PartCounter}        || 0;
     my $SubPartCounter     = $Param{SubPartCounter}     || 0;
     my $ContentAlternative = $Param{ContentAlternative} || '';
-    my $ContentMixed       = $Param{ContentMixed}       || '';
     $Self->{PartCounter}++;
     if ( $Part->parts() > 0 ) {
 
         # check if it's an alternative part
+        my $ContentAlternative;
         $Part->head()->unfold();
         $Part->head()->combine('Content-Type');
         my $ContentType = $Part->head()->get('Content-Type');
         if ( $ContentType && $ContentType =~ /multipart\/alternative;/i ) {
             $ContentAlternative = 1;
         }
-        if ( $ContentType && $ContentType =~ /multipart\/mixed;/i ) {
-            $ContentMixed = 1;
-        }
         $PartCounter++;
         for my $Part ( $Part->parts() ) {
             $SubPartCounter++;
@@ -649,7 +665,6 @@ sub PartsAttachments {
                 Part               => $Part,
                 PartCounter        => $PartCounter,
                 ContentAlternative => $ContentAlternative,
-                ContentMixed       => $ContentMixed,
             );
         }
         return 1;
@@ -658,6 +673,7 @@ sub PartsAttachments {
     # get attachment meta stuff
     my %PartData;
 
+    # get content alternative
     if ($ContentAlternative) {
         $PartData{ContentAlternative} = $ContentAlternative;
     }
@@ -670,9 +686,6 @@ sub PartsAttachments {
     $PartData{ContentType} = $Part->head()->get('Content-Type') || 'text/plain;';
     chomp $PartData{ContentType};
 
-    # Fix for broken content type headers, see bug#7913 or DuplicatedContentTypeHeader.t.
-    $PartData{ContentType} =~ s{\r?\n}{}smxg;
-
     # get mime type
     $PartData{MimeType} = $Part->head()->mime_type();
 
@@ -689,16 +702,17 @@ sub PartsAttachments {
     if ( $Part->bodyhandle() ) {
         $PartData{Content} = $Part->bodyhandle()->as_string();
         if ( !$PartData{Content} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $Self->{LogObject}->Log(
                 Priority => 'notice',
-                Message  => "Empty attachment part ($PartCounter)",
+                Message  => "Totally empty attachment part ($PartCounter)",
             );
+            return;
         }
     }
 
     # log error if there is an corrupt MIME email
     else {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'notice',
             Message =>
                 "Was not able to parse corrupt MIME email! Skipped attachment ($PartCounter)",
@@ -708,17 +722,7 @@ sub PartsAttachments {
 
     # check if there is no recommended_filename or subject -> add file-NoFilenamePartCounter
     if ( $Part->head()->recommended_filename() ) {
-        $PartData{Filename} = $Self->_DecodeString(
-            String => $Part->head()->recommended_filename(),
-            Encode => 'utf-8',
-        );
-
-        # cleanup filename
-        $PartData{Filename} = $Kernel::OM->Get('Kernel::System::Main')->FilenameCleanUp(
-            Filename => $PartData{Filename},
-            Type     => 'Local',
-        );
-
+        $PartData{Filename}           = decode_mimewords( $Part->head()->recommended_filename() );
         $PartData{ContentDisposition} = $Part->head()->get('Content-Disposition');
         if ( $PartData{ContentDisposition} ) {
             my %Data = $Self->GetContentTypeParams(
@@ -732,43 +736,58 @@ sub PartsAttachments {
             $PartData{Charset} = '';
         }
 
-        # check if reserved filename file-1 or file-2 is already used
-        COUNT:
+        # convert the file name in utf-8 if utf-8 is used
+        if ( $PartData{Charset} ) {
+            $PartData{Filename} = $Self->{EncodeObject}->Convert2CharsetInternal(
+                Text  => $PartData{Filename},
+                From  => $PartData{Charset},
+                Check => 1,
+            );
+        }
+
+        # check if reserved filenames file-1 or file-2 is already used
         for my $Count ( 1 .. 2 ) {
             if ( $PartData{Filename} eq "file-$Count" ) {
                 $PartData{Filename} = "File-$Count";
-                last COUNT;
+                last;
             }
         }
     }
 
     # Guess the filename for nested messages (see bug#1970).
     elsif ( $PartData{ContentType} eq 'message/rfc822' ) {
+        my ($SubjectString) = $Part->as_string =~ m/^Subject: ([^\n]*(\n[ \t][^\n]*)*)/m;
+        my $Subject;
+        foreach my $Decoded ( decode_mimewords($SubjectString) ) {
+            if ( $Decoded->[0] ) {
+                $Subject .= $Self->{EncodeObject}->Convert2CharsetInternal(
+                    Text  => $Decoded->[0],
+                    From  => $Decoded->[1] || 'us-ascii',
+                    Check => 1,
+                );
+            }
+        }
 
-        my ($SubjectString) = $Part->as_string() =~ m/^Subject: ([^\n]*(\n[ \t][^\n]*)*)/m;
-        my $Subject = $Self->_DecodeString( String => $SubjectString ) . '.eml';
-
-        # cleanup filename
-        $Subject = $Kernel::OM->Get('Kernel::System::Main')->FilenameCleanUp(
-            Filename => $Subject,
-            Type     => 'Local',
-        );
+        # trim whitespace
+        $Subject =~ s/^\s+|\n|\s+$//;
+        if ( length($Subject) > 246 ) {
+            $Subject = substr( $Subject, 0, 246 );
+        }
 
         if ( $Subject eq '' ) {
             $Self->{NoFilenamePartCounter}++;
-            $Subject = "Untitled-$Self->{NoFilenamePartCounter}" . '.eml';
+            $Subject = "Unbenannt-$Self->{NoFilenamePartCounter}";
         }
-        $PartData{Filename} = $Subject;
+        $PartData{Filename} = $Subject . '.eml';
     }
     else {
         $Self->{NoFilenamePartCounter}++;
         $PartData{Filename} = "file-$Self->{NoFilenamePartCounter}";
     }
 
-    # parse/get Content-Id, Content-Location and Disposition for html email attachments
+    # parse/get Content-Id and Content-Location for html email attachments
     $PartData{ContentID}       = $Part->head()->get('Content-Id');
     $PartData{ContentLocation} = $Part->head()->get('Content-Location');
-    $PartData{Disposition}     = $Part->head()->get('Content-Disposition');
 
     if ( $PartData{ContentID} ) {
         chomp $PartData{ContentID};
@@ -777,10 +796,6 @@ sub PartsAttachments {
         chomp $PartData{ContentLocation};
         $PartData{ContentID} = $PartData{ContentLocation};
     }
-    if ( $PartData{Disposition} ) {
-        chomp $PartData{Disposition};
-        $PartData{Disposition} = lc $PartData{Disposition};
-    }
 
     # get attachment size
     $PartData{Filesize} = bytes::length( $PartData{Content} );
@@ -791,98 +806,12 @@ sub PartsAttachments {
             "->GotArticle::Atm: '$PartData{Filename}' '$PartData{ContentType}' ($PartData{Filesize})\n";
     }
 
-    # For multipart/mixed emails, we check for all text/plain or text/html MIME parts which are
-    #   body elements, and concatenate them into the first relevant attachment, to stay in line
-    #   with OTRS file-1 and file-2 attachment handling.
-    #
-    # HTML parts will just be concatenated, so that the attachment has two complete HTML documents
-    #   inside. Browsers tolerate this.
-    #
-    # The first found body part determines the content type to be used. So if it is text/plain, subsequent
-    #   text/html body parts will be converted to plain text, and vice versa. In case of multipart/alternative,
-    #   a text/plain and a text/html body attachment can coexist.
-    if (
-        $ContentMixed
-        && ( !$PartData{Disposition} || $PartData{Disposition} eq 'inline' )
-        && ( $PartData{ContentType} =~ /text\/(?:html|plain)/i )
-        )
-    {
-        # Is it a plain or HTML body?
-        my $MimeType       = $PartData{ContentType} =~ /text\/html/i ? 'text/html' : 'text/plain';
-        my $TargetMimeType = $MimeType;
-
-        my $BodyAttachmentKey = "MultipartMixedBodyAttachment$MimeType";
-
-        if ( !$Self->{FirstBodyAttachmentKey} ) {
-
-            # Remember the first found attachment.
-            $Self->{FirstBodyAttachmentKey}      = $BodyAttachmentKey;
-            $Self->{FirstBodyAttachmentMimeType} = $MimeType;
-        }
-        elsif ( !$ContentAlternative ) {
-
-            # For multipart/alternative, we allow both text/plain and text/html. Otherwise, concatenate
-            #   all subsequent elements to the first found body element.
-            $BodyAttachmentKey = $Self->{FirstBodyAttachmentKey};
-            $TargetMimeType    = $Self->{FirstBodyAttachmentMimeType};
-        }
-
-        # For concatenating multipart/mixed text parts, we have to convert all of them to utf-8 to be sure that
-        #   the contents fit together and that all characters can be displayed.
-        $PartData{Content} = $Kernel::OM->Get('Kernel::System::Encode')->Convert2CharsetInternal(
-            Text  => $PartData{Content},
-            From  => $PartData{Charset},
-            Check => 1,
-        );
-        $PartData{ContentType} = "$MimeType; charset=utf-8";
-        my $OldCharset = $PartData{Charset};
-        $PartData{Charset} = "utf-8";
-
-        # Also replace charset in meta tags of HTML emails.
-        if ( $MimeType eq 'text/html' ) {
-            $PartData{Content} =~ s/(<meta[^>]+charset=("|'|))\Q$OldCharset\E/$1utf-8/gi;
-        }
-
-        $PartData{Filesize} = bytes::length( $PartData{Content} );
-
-        # Is it a subsequent body element? Then concatenate it to the first one and skip it as attachment.
-        if ( $Self->{$BodyAttachmentKey} ) {
-
-            # This concatenation only works if all parts have the utf-8 flag on (from Convert2CharsetInternal).
-            if ( $MimeType ne $TargetMimeType ) {
-                my $HTMLUtilsObject = $Kernel::OM->Get('Kernel::System::HTMLUtils');
-                if ( $TargetMimeType eq 'text/html' ) {
-                    my $HTMLContent = $HTMLUtilsObject->ToHTML(
-                        String => $PartData{Content},
-                    );
-                    $PartData{Content} = $HTMLUtilsObject->DocumentComplete(
-                        String  => $HTMLContent,
-                        Charset => 'utf-8',
-                    );
-                }
-                else {
-                    $PartData{Content} = $HTMLUtilsObject->ToAscii(
-                        String => $PartData{Content},
-                    );
-                }
-                $PartData{Filesize} = bytes::length( $PartData{Content} );
-            }
-            $Self->{$BodyAttachmentKey}->{Content} .= $PartData{Content};
-            $Self->{$BodyAttachmentKey}->{Filesize} += $PartData{Filesize};
-
-            # Don't create an attachment for this part, as it was concatenated to the first body element.
-            return 1;
-        }
-
-        # Remember the first found body element for possible later concatenation.
-        $Self->{$BodyAttachmentKey} = \%PartData;
-    }
-
+    # store data
     push @{ $Self->{Attachments} }, \%PartData;
     return 1;
 }
 
-=head2 GetReferences()
+=item GetReferences()
 
 To get an array of reference ids of the parsed email
 
@@ -967,12 +896,12 @@ sub CheckMessageBody {
     return if $Self->{MessageChecked};
 
     # return if no auto convert from html2text is needed
-    return if !$Kernel::OM->Get('Kernel::Config')->Get('PostmasterAutoHTML2Text');
+    return if !$Self->{ConfigObject}->Get('PostmasterAutoHTML2Text');
 
     # return if no auto convert from html2text is needed
     return if $Self->{NoHTMLChecks};
 
-    # check if it's just a html email (store it as attachment and add text/plain)
+    # check it it's juat a html email (store it as attachment and add text/plain)
     if ( $Self->GetReturnContentType() =~ /text\/html/i ) {
         $Self->{MessageChecked} = 1;
 
@@ -989,7 +918,7 @@ sub CheckMessageBody {
             );
         }
 
-        # add .html suffix to filename if not aleady there
+        # remember to html file if not aleady there
         else {
             if ( $Self->{Attachments}->[0]->{Filename} ) {
                 if ( $Self->{Attachments}->[0]->{Filename} !~ /\.(htm|html)/i ) {
@@ -998,121 +927,40 @@ sub CheckMessageBody {
             }
         }
 
-        # remember to be a mime email now
+        # remember to be an mime email now
         $Self->{MimeEmail} = 1;
 
         # convert from html to ascii
-        $Self->{MessageBody} = $Kernel::OM->Get('Kernel::System::HTMLUtils')->ToAscii(
+        $Self->{MessageBody} = $Self->{HTMLUtilsObject}->ToAscii(
             String => $Self->{MessageBody},
         );
 
         $Self->{ContentType} = 'text/plain';
         if ( $Self->{Debug} > 0 ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $Self->{LogObject}->Log(
                 Priority => 'debug',
                 Message =>
                     'It\'s an html only email, added ascii dump, attached html email as attachment.',
             );
         }
     }
-
     return;
 }
 
-=begin Internal:
+1;
 
-=head2 _DecodeString()
-
-Decode all encoded substrings.
-
-    my $Result = $Self->_DecodeString(
-        String => 'some text',
-    );
-
-=cut
-
-sub _DecodeString {
-    my ( $Self, %Param ) = @_;
-
-    # get encode object
-    my $EncodeObject = $Kernel::OM->Get('Kernel::System::Encode');
-
-    my $DecodedString;
-    my $BufferedString;
-    my $PrevEncoding;
-
-    $BufferedString = '';
-
-    # call MIME::Words::decode_mimewords()
-    for my $Entry ( decode_mimewords( $Param{String} ) ) {
-        if (
-            $BufferedString ne ''
-            && ( !$PrevEncoding || !$Entry->[1] || lc($PrevEncoding) ne lc( $Entry->[1] ) )
-            )
-        {
-            my $Encoding = $EncodeObject->FindAsciiSupersetEncoding(
-                Encodings => [ $PrevEncoding, $Param{Encode}, $Self->GetCharset() ],
-            );
-            $DecodedString .= $EncodeObject->Convert2CharsetInternal(
-                Text  => $BufferedString,
-                From  => $Encoding,
-                Check => 1,
-            );
-            $BufferedString = '';
-        }
-        $BufferedString .= $Entry->[0];
-        $PrevEncoding = $Entry->[1];
-    }
-
-    if ( $BufferedString ne '' ) {
-        my $Encoding = $EncodeObject->FindAsciiSupersetEncoding(
-            Encodings => [ $PrevEncoding, $Param{Encode}, $Self->GetCharset() ],
-        );
-        $DecodedString .= $EncodeObject->Convert2CharsetInternal(
-            Text  => $BufferedString,
-            From  => $Encoding,
-            Check => 1,
-        );
-    }
-
-    return $DecodedString;
-}
-
-=head2 _MailAddressParse()
-
-    my @Chunks = $ParserObject->_MailAddressParse(Email => $Email);
-
-Wrapper for C<Mail::Address->parse($Email)>, but cache it, since it's
-not too fast, and often called.
-
-=cut
-
-sub _MailAddressParse {
-    my ( $Self, %Param ) = @_;
-
-    my $Email = $Param{Email};
-    my $Cache = $Self->{EmailCache};
-
-    if ( $Self->{EmailCache}->{$Email} ) {
-        return @{ $Self->{EmailCache}->{$Email} };
-    }
-
-    my @Chunks = Mail::Address->parse($Email);
-    $Self->{EmailCache}->{$Email} = \@Chunks;
-
-    return @Chunks;
-}
-
-=end Internal:
+=back
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+
+=head1 VERSION
+
+$Revision: 1.107.2.1 $ $Date: 2012-11-29 12:42:28 $
 
 =cut
-
-1;
