@@ -1,9 +1,12 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/System/GenericAgent/TriggerEscalationStartEvents.pm - trigger escalation start events
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# --
+# $Id: TriggerEscalationStartEvents.pm,v 1.3.2.1 2012-05-21 14:04:48 cg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::GenericAgent::TriggerEscalationStartEvents;
@@ -11,16 +14,13 @@ package Kernel::System::GenericAgent::TriggerEscalationStartEvents;
 use strict;
 use warnings;
 
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.3.2.1 $) [1];
+
 use List::Util qw(first);
 
-our @ObjectDependencies = (
-    'Kernel::Config',
-    'Kernel::System::DateTime',
-    'Kernel::System::Log',
-    'Kernel::System::Queue',
-    'Kernel::System::SLA',
-    'Kernel::System::Ticket',
-);
+use Kernel::System::SLA;
+use Kernel::System::Queue;
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -29,62 +29,76 @@ sub new {
     my $Self = {};
     bless $Self, $Type;
 
+    # check needed objects
+    for (qw(DBObject ConfigObject LogObject TicketObject TimeObject EncodeObject MainObject)) {
+        $Self->{$_} = $Param{$_} || die "Got no $_!";
+    }
+
     # 0=off; 1=on;
     $Self->{Debug} = $Param{Debug} || 0;
 
+    $Self->{SLAObject}   = Kernel::System::SLA->new( %{$Self} );
+    $Self->{QueueObject} = Kernel::System::Queue->new( %{$Self} );
+
     return $Self;
 }
 
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    # get ticket object
-    my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
-
     # get ticket data
     # the escalation properties are computed within TicketGet().
-    my %Ticket = $TicketObject->TicketGet(
+    my %Ticket = $Self->{TicketObject}->TicketGet(
         %Param,
         DynamicFields => 0,
     );
 
-    # get used calendar
-    my $Calendar = $TicketObject->TicketCalendarGet(
-        %Ticket,
-    );
+    my $Calendar;
 
-    # get time object
-    my $StopDateTimeObject = $Kernel::OM->Create('Kernel::System::DateTime');
+    # check if ticket has an assigned SLA with a defined calendar
+    if ( $Ticket{SLAID} ) {
+        my %SLAData = $Self->{SLAObject}->SLAGet(
+            SLAID  => $Ticket{SLAID},
+            UserID => 1,
+        );
 
-    # check if it is during business hours, then send escalation info
-    my $StartDateTimeObject = $Kernel::OM->Create(
-        'Kernel::System::DateTime',
-        ObjectParams => {
-            Epoch => $StopDateTimeObject->ToEpoch() - ( 10 * 60 ),
+        # set $Calendar if SLA has a defined calendar
+        $Calendar = $SLAData{Calendar} ? $SLAData{Calendar} : '';
+    }
+
+    # check if there was no $Calendar defined via SLA
+    if ( !$Calendar ) {
+
+        # check if ticket queue has a defined calendar
+        if ( $Ticket{QueueID} ) {
+            my %QueueData = $Self->{QueueObject}->QueueGet(
+                ID => $Ticket{QueueID},
+            );
+
+            # set $Calendar if SLA has a defined calendar
+            $Calendar = $QueueData{Calendar} ? $QueueData{Calendar} : '';
         }
+    }
+
+    # do not trigger escalation start events outside busincess hours
+    my $CountedTime = $Self->{TimeObject}->WorkingTime(
+        StartTime => $Self->{TimeObject}->SystemTime() - ( 10 * 60 ),
+        StopTime => $Self->{TimeObject}->SystemTime(),
+        Calendar => $Calendar || '',
     );
-
-    my $CountedTime = $StartDateTimeObject->Delta(
-        DateTimeObject => $StopDateTimeObject,
-        ForWorkingTime => 1,
-        Calendar       => $Calendar,
-    );
-
-    if ( !$CountedTime || !$CountedTime->{AbsoluteSeconds} ) {
-
+    if ( !$CountedTime ) {
         if ( $Self->{Debug} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $Self->{LogObject}->Log(
                 Priority => 'debug',
                 Message =>
                     "Send not escalation for Ticket $Ticket{TicketNumber}/$Ticket{TicketID} because currently no working hours!",
             );
         }
-
         return 1;
     }
 
     # needed for deciding whether events should be triggered
-    my @HistoryLines = $TicketObject->HistoryGet(
+    my @HistoryLines = $Self->{TicketObject}->HistoryGet(
         TicketID => $Ticket{TicketID},
         UserID   => 1,
     );
@@ -107,26 +121,21 @@ sub Run {
     for my $Attr ( grep { defined $Ticket{$_} } sort keys %TicketAttr2Event ) {
 
         # the decay time is configured in minutes
-        my $DecayTimeInSeconds = $Kernel::OM->Get('Kernel::Config')->Get('OTRSEscalationEvents::DecayTime') || 0;
-
+        my $DecayTimeInSeconds
+            = $Self->{ConfigObject}->Get('OTRSEscalationEvents::DecayTime') || 0;
         $DecayTimeInSeconds *= 60;
 
         # get the last time this event was triggered
         # search in reverse order, as @HistoryLines sorted ascendingly by CreateTime
         if ($DecayTimeInSeconds) {
-            my $PrevEventLine = first { $_->{HistoryType} eq $TicketAttr2Event{$Attr} }
+            my $PrevEventLine
+                = first { $_->{HistoryType} eq $TicketAttr2Event{$Attr} }
             reverse @HistoryLines;
             if ( $PrevEventLine && $PrevEventLine->{CreateTime} ) {
-
-                my $PrevEventTime = $Kernel::OM->Create(
-                    'Kernel::System::DateTime',
-                    ObjectParams => {
-                        String => $PrevEventLine->{CreateTime},
-                    },
+                my $PrevEventTime = $Self->{TimeObject}->TimeStamp2SystemTime(
+                    String => $PrevEventLine->{CreateTime},
                 );
-                $PrevEventTime = $PrevEventTime ? $PrevEventTime->ToEpoch() : 0;
-
-                my $TimeSincePrevEvent = $StopDateTimeObject->ToEpoch() - $PrevEventTime;
+                my $TimeSincePrevEvent = $Self->{TimeObject}->SystemTime() - $PrevEventTime;
 
                 next ATTR if $TimeSincePrevEvent <= $DecayTimeInSeconds;
             }
@@ -139,7 +148,7 @@ sub Run {
     for my $Event (@Events) {
 
         # trigger the event
-        $TicketObject->EventHandler(
+        $Self->{TicketObject}->EventHandler(
             Event  => $Event,
             UserID => 1,
             Data   => {
@@ -149,7 +158,7 @@ sub Run {
         );
 
         # log the triggered event in the history
-        $TicketObject->HistoryAdd(
+        $Self->{TicketObject}->HistoryAdd(
             TicketID     => $Param{TicketID},
             HistoryType  => $Event,
             Name         => "%%$Event%%triggered",
