@@ -1,9 +1,12 @@
 # --
-# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
+# Kernel/System/PostMaster/LoopProtection/FS.pm - backend module of LoopProtection
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# --
+# $Id: FS.pm,v 1.13 2009-02-16 11:47:35 tr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::PostMaster::LoopProtection::FS;
@@ -11,21 +14,32 @@ package Kernel::System::PostMaster::LoopProtection::FS;
 use strict;
 use warnings;
 
-use parent 'Kernel::System::PostMaster::LoopProtectionCommon';
-
-our @ObjectDependencies = (
-    'Kernel::Config',
-    'Kernel::System::Log',
-    'Kernel::System::DateTime',
-);
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.13 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
-    my $Self = $Type->SUPER::new(%Param);
 
-    $Self->{LoopProtectionLog} = $Kernel::OM->Get('Kernel::Config')->Get('LoopProtectionLog')
+    # allocate new hash for object
+    my $Self = {};
+    bless( $Self, $Type );
+
+    # get needed  objects
+    for (qw(DBObject LogObject ConfigObject)) {
+        $Self->{$_} = $Param{$_} || die "Got no $_!";
+    }
+
+    # get config options
+    $Self->{LoopProtectionLog} = $Self->{ConfigObject}->Get('LoopProtectionLog')
         || die 'No Config option "LoopProtectionLog"!';
-    $Self->{LoopProtectionLog} .= '-' . $Self->{LoopProtectionDate} . '.log';
+
+    $Self->{PostmasterMaxEmails} = $Self->{ConfigObject}->Get('PostmasterMaxEmails') || 40;
+
+    # create logfile name
+    my ( $Sec, $Min, $Hour, $Day, $Month, $Year ) = localtime(time);
+    $Year = $Year + 1900;
+    $Month++;
+    $Self->{LoopProtectionLog} .= '-' . $Year . '-' . $Month . '-' . $Day . '.log';
 
     return $Self;
 }
@@ -36,15 +50,12 @@ sub SendEmail {
     my $To = $Param{To} || return;
 
     # write log
-    ## no critic
     if ( open( my $Out, '>>', $Self->{LoopProtectionLog} ) ) {
-        my $DateTimeObject = $Kernel::OM->Create('Kernel::System::DateTime');
-        ## use critic
-        print $Out "$To;" . $DateTimeObject->Format( Format => '%a %b %{day} %H:%M:%S %Y' ) . ";\n";    ## no critic
+        print $Out "$To;" . localtime() . ";\n";
         close($Out);
     }
     else {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'error',
             Message  => "LoopProtection! Can't write '$Self->{LoopProtectionLog}': $!!",
         );
@@ -56,19 +67,15 @@ sub SendEmail {
 sub Check {
     my ( $Self, %Param ) = @_;
 
-    my $To    = $Param{To} || return;
+    my $To = $Param{To} || return;
     my $Count = 0;
 
     # check existing logfile
-    ## no critic
     if ( !open( my $In, '<', $Self->{LoopProtectionLog} ) ) {
-        ## use critic
 
         # create new log file
-        ## no critic
         if ( !open( my $Out, '>', $Self->{LoopProtectionLog} ) ) {
-            ## use critic
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
+            $Self->{LogObject}->Log(
                 Priority => 'error',
                 Message  => "LoopProtection! Can't write '$Self->{LoopProtectionLog}': $!!",
             );
@@ -90,17 +97,14 @@ sub Check {
     }
 
     # check possible loop
-    my $Max = $Self->{PostmasterMaxEmailsPerAddress}{ lc $To } // $Self->{PostmasterMaxEmails};
-
-    if ( $Max && $Count >= $Max ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+    if ( $Count >= $Self->{PostmasterMaxEmails} ) {
+        $Self->{LogObject}->Log(
             Priority => 'notice',
             Message =>
-                "LoopProtection: send no more emails to '$To'! Max. count of $Self->{PostmasterMaxEmails} has been reached!",
+                "LoopProtection!!! Send no more emails to '$To'! Max. count of $Self->{PostmasterMaxEmails} has been reached!",
         );
         return;
     }
-
     return 1;
 }
 
