@@ -1,9 +1,12 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/System/VariableCheck.pm - helpers to check variables
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# --
+# $Id: VariableCheck.pm,v 1.6 2011-11-08 09:43:04 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::VariableCheck;
@@ -11,8 +14,11 @@ package Kernel::System::VariableCheck;
 use strict;
 use warnings;
 
-use Exporter qw(import);
-our %EXPORT_TAGS = (    ## no critic
+use vars qw(@ISA $VERSION @EXPORT_OK %EXPORT_TAGS);
+$VERSION = qw($Revision: 1.6 $) [1];
+
+use Exporter;
+%EXPORT_TAGS = (
     all => [
         'IsArrayRefWithData',
         'IsHashRefWithData',
@@ -30,11 +36,13 @@ our %EXPORT_TAGS = (    ## no critic
 );
 Exporter::export_ok_tags('all');
 
+@ISA = qw(Exporter);
+
 =head1 NAME
 
 Kernel::System::VariableCheck - helper functions to check variables
 
-=head1 DESCRIPTION
+=head1 SYNOPSIS
 
 Provides several helper functions to check variables, e.g.
 if a variable is a string, a hash ref etc. This is helpful for
@@ -43,7 +51,7 @@ input data validation, for example.
 Call this module directly without instantiating:
 
     use Kernel::System::VariableCheck qw(:all);             # export all functions into the calling package
-    use Kernel::System::VariableCheck qw(IsHashRefWitData); # export just one function
+    use Kernel::System::VariableCheck qw(IsHashRefWitData); # export just one funciton
 
     if (IsHashRefWithData($HashRef)) {
         ...
@@ -55,13 +63,13 @@ The functions can be grouped as follows:
 
 =over 4
 
-=item * L</IsString()>
+=item L<IsString()>
 
-=item * L</IsStringWithData()>
+=item L<IsStringWithData()>
 
-=item * L</IsArrayRefWithData()>
+=item L<IsArrayRefWithData()>
 
-=item * L</IsHashRefWithData()>
+=item L<IsHashRefWithData()>
 
 =back
 
@@ -69,11 +77,11 @@ The functions can be grouped as follows:
 
 =over 4
 
-=item * L</IsNumber()>
+=item L<IsNumber()>
 
-=item * L</IsInteger()>
+=item L<IsInteger()>
 
-=item * L</IsPositiveInteger()>
+=item L<IsPositiveInteger()>
 
 =back
 
@@ -81,17 +89,21 @@ The functions can be grouped as follows:
 
 =over 4
 
-=item * L</IsIPv4Address()>
+=item L<IsIPv4Address()>
 
-=item * L</IsIPv6Address()>
+=item L<IsIPv6Address()>
 
-=item * L</IsMD5Sum()>
+=item L<IsMD5Sum()>
 
 =back
 
 =head1 PUBLIC INTERFACE
 
-=head2 IsString()
+=over 4
+
+=cut
+
+=item IsString()
 
 test supplied data to determine if it is a string - an empty string is valid
 
@@ -103,8 +115,6 @@ returns 1 if data matches criteria or undef otherwise
 
 =cut
 
-## no critic (Perl::Critic::Policy::Subroutines::RequireArgUnpacking)
-
 sub IsString {
     my $TestData = $_[0];
 
@@ -115,7 +125,7 @@ sub IsString {
     return 1;
 }
 
-=head2 IsStringWithData()
+=item IsStringWithData()
 
 test supplied data to determine if it is a non zero-length string
 
@@ -136,9 +146,9 @@ sub IsStringWithData {
     return 1;
 }
 
-=head2 IsArrayRefWithData()
+=item IsArrayRefWithData()
 
-test supplied data to determine if it is an array reference and contains at least one key
+test supplied data to deterine if it is an array reference and contains at least one key
 
 returns 1 if data matches criteria or undef otherwise
 
@@ -161,9 +171,9 @@ sub IsArrayRefWithData {
     return 1;
 }
 
-=head2 IsHashRefWithData()
+=item IsHashRefWithData()
 
-test supplied data to determine if it is a hash reference and contains at least one key/value pair
+test supplied data to deterine if it is a hash reference and contains at least one key/value pair
 
 returns 1 if data matches criteria or undef otherwise
 
@@ -186,7 +196,7 @@ sub IsHashRefWithData {
     return 1;
 }
 
-=head2 IsNumber()
+=item IsNumber()
 
 test supplied data to determine if it is a number
 (integer, floating point, possible exponent, positive or negative)
@@ -210,7 +220,7 @@ sub IsNumber {
     return 1;
 }
 
-=head2 IsInteger()
+=item IsInteger()
 
 test supplied data to determine if it is an integer (only digits, positive or negative)
 
@@ -231,7 +241,7 @@ sub IsInteger {
     return 1;
 }
 
-=head2 IsPositiveInteger()
+=item IsPositiveInteger()
 
 test supplied data to determine if it is a positive integer (only digits and positive)
 
@@ -252,7 +262,7 @@ sub IsPositiveInteger {
     return 1;
 }
 
-=head2 IsIPv4Address()
+=item IsIPv4Address()
 
 test supplied data to determine if it is a valid IPv4 address (syntax check only)
 
@@ -277,14 +287,14 @@ sub IsIPv4Address {
 
         # allow numbers 0 to 255, no leading zeroes
         return if $Part !~ m{
-            \A (?: \d | [1-9] \d | [1] \d{2} | [2][0-4]\d | [2][5][0-5] ) \z
+            \A (?: \d | [1-9] \d | [1] \d\{2\} | [2][0-4]\d | [2][5][0-5] ) \z
         }xms;
     }
 
     return 1;
 }
 
-=head2 IsIPv6Address()
+=item IsIPv6Address()
 
 test supplied data to determine if it is a valid IPv6 address (syntax check only)
 shorthand notation and mixed IPv6/IPv4 notation allowed
@@ -368,9 +378,9 @@ sub IsIPv6Address {
     return 1;
 }
 
-=head2 IsMD5Sum()
+=item IsMD5Sum()
 
-test supplied data to determine if it is an C<MD5> sum (32 hex characters)
+test supplied data to determine if it is an md5sum (32 hex characters)
 
 returns 1 if data matches criteria or undef otherwise
 
@@ -389,7 +399,7 @@ sub IsMD5Sum {
     return 1;
 }
 
-=head2 DataIsDifferent()
+=item DataIsDifferent()
 
 compares two data structures with each other. Returns 1 if
 they are different, undef otherwise.
@@ -397,7 +407,7 @@ they are different, undef otherwise.
 Data parameters need to be passed by reference and can be SCALAR,
 ARRAY or HASH.
 
-    my $DataIsDifferent = DataIsDifferent(
+    my $DataIsDifferent = DataDiff(
         Data1 => \$Data1,
         Data2 => \$Data2,
     );
@@ -407,6 +417,11 @@ ARRAY or HASH.
 sub DataIsDifferent {
     my (%Param) = @_;
 
+    # check needed stuff
+    for (qw(Data1 Data2)) {
+        return if ( !defined $Param{$_} );
+    }
+
     # ''
     if ( ref $Param{Data1} eq '' && ref $Param{Data2} eq '' ) {
 
@@ -448,22 +463,18 @@ sub DataIsDifferent {
         return 1 if $#A ne $#B;
 
         # compare array
-        COUNT:
         for my $Count ( 0 .. $#A ) {
 
             # do nothing, it's ok
-            next COUNT if !defined $A[$Count] && !defined $B[$Count];
+            next if !defined $A[$Count] && !defined $B[$Count];
 
             # return diff, because its different
             return 1 if !defined $A[$Count] || !defined $B[$Count];
 
             if ( $A[$Count] ne $B[$Count] ) {
                 if ( ref $A[$Count] eq 'ARRAY' || ref $A[$Count] eq 'HASH' ) {
-                    return 1 if DataIsDifferent(
-                        Data1 => $A[$Count],
-                        Data2 => $B[$Count]
-                    );
-                    next COUNT;
+                    return 1 if DataIsDifferent( Data1 => $A[$Count], Data2 => $B[$Count] );
+                    next;
                 }
                 return 1;
             }
@@ -477,14 +488,13 @@ sub DataIsDifferent {
         my %B = %{ $Param{Data2} };
 
         # compare %A with %B and remove it if checked
-        KEY:
-        for my $Key ( sort keys %A ) {
+        for my $Key ( keys %A ) {
 
             # Check if both are undefined
             if ( !defined $A{$Key} && !defined $B{$Key} ) {
                 delete $A{$Key};
                 delete $B{$Key};
-                next KEY;
+                next;
             }
 
             # return diff, because its different
@@ -493,18 +503,15 @@ sub DataIsDifferent {
             if ( $A{$Key} eq $B{$Key} ) {
                 delete $A{$Key};
                 delete $B{$Key};
-                next KEY;
+                next;
             }
 
             # return if values are different
             if ( ref $A{$Key} eq 'ARRAY' || ref $A{$Key} eq 'HASH' ) {
-                return 1 if DataIsDifferent(
-                    Data1 => $A{$Key},
-                    Data2 => $B{$Key}
-                );
+                return 1 if DataIsDifferent( Data1 => $A{$Key}, Data2 => $B{$Key} );
                 delete $A{$Key};
                 delete $B{$Key};
-                next KEY;
+                next;
             }
             return 1;
         }
@@ -515,10 +522,7 @@ sub DataIsDifferent {
     }
 
     if ( ref $Param{Data1} eq 'REF' && ref $Param{Data2} eq 'REF' ) {
-        return 1 if DataIsDifferent(
-            Data1 => ${ $Param{Data1} },
-            Data2 => ${ $Param{Data2} }
-        );
+        return 1 if DataIsDifferent( Data1 => ${ $Param{Data1} }, Data2 => ${ $Param{Data2} } );
         return;
     }
 
@@ -527,12 +531,20 @@ sub DataIsDifferent {
 
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+
+=cut
+
+=head1 VERSION
+
+$Revision: 1.6 $ $Date: 2011-11-08 09:43:04 $
 
 =cut
