@@ -1,9 +1,9 @@
 #!/usr/bin/perl -w
 # --
 # bin/fcgi-bin/public.pl - the global FastCGI handle file for OTRS
-# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
-# $Id: public.pl,v 1.2 2009/12/02 08:43:54 mb Exp $
+# $Id: public.pl,v 1.4 2011-03-08 14:15:54 mb Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -17,7 +17,7 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -28,12 +28,10 @@ use warnings;
 use FindBin qw($Bin);
 use lib "$Bin/../..";
 use lib "$Bin/../../Kernel/cpan-lib";
+use lib "$Bin/../../Custom";
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.2 $)[1];
-
-# check @INC for mod_perl (add lib path for "require module"!)
-push (@INC, "$Bin/../..", "$Bin/../../Kernel/cpan-lib");
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.4 $) [1];
 
 # Imports the library; required line
 use CGI::Fast;
@@ -43,15 +41,19 @@ use Kernel::System::Web::InterfacePublic();
 
 # 0=off;1=on;
 my $Debug = 0;
+
 #my $Cnt = 0;
 
 # Response loop
-while (my $WebRequest = new CGI::Fast) {
+while ( my $WebRequest = new CGI::Fast ) {
+
     # create new object
-    my $Interface = Kernel::System::Web::InterfacePublic->new(Debug => $Debug, WebRequest => $WebRequest);
+    my $Interface
+        = Kernel::System::Web::InterfacePublic->new( Debug => $Debug, WebRequest => $WebRequest );
 
     # execute object
     $Interface->Run();
-#    $Cnt++;
-#    print STDERR "This is connection number $Cnt\n";
+
+    #    $Cnt++;
+    #    print STDERR "This is connection number $Cnt\n";
 }
