@@ -1,6 +1,9 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -w
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# bin/otrs.AddRole2Group.pl - Assign Roles to Groups from CLI
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# --
+# $Id: otrs.AddRole2Group.pl,v 1.4 2010-08-06 17:49:20 cr Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,23 +12,25 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 use strict;
 use warnings;
 
+# use ../ as lib location
 use File::Basename;
 use FindBin qw($RealBin);
 use lib dirname($RealBin);
-use lib dirname($RealBin) . '/Kernel/cpan-lib';
-use lib dirname($RealBin) . '/Custom';
+
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.4 $) [1];
 
 use Getopt::Std;
 use Kernel::Config;
@@ -37,24 +42,12 @@ use Kernel::System::Queue;
 use Kernel::System::Group;
 use Kernel::System::Main;
 
-# create common objects
-my %CommonObject = ();
-$CommonObject{ConfigObject} = Kernel::Config->new(%CommonObject);
-$CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
-$CommonObject{LogObject}    = Kernel::System::Log->new(
-    LogPrefix => 'OTRS-otrs.AddRole2Group.pl',
-    %CommonObject,
-);
-$CommonObject{MainObject}  = Kernel::System::Main->new(%CommonObject);
-$CommonObject{DBObject}    = Kernel::System::DB->new(%CommonObject);
-$CommonObject{GroupObject} = Kernel::System::Group->new(%CommonObject);
-
 # get options
-my %Opts;
+my %Opts = ();
 getopts( 'hg:r:R:M:C:N:O:P:W:', \%Opts );
 if ( $Opts{h} ) {
-    print "otrs.AddRole2Group.pl - assign Roles to Groups\n";
-    print "Copyright (C) 2001-2017 OTRS AG, http://otrs.com/\n";
+    print "otrs.AddRole2Group.pl <Revision $VERSION> - assign Roles to Groups\n";
+    print "Copyright (C) 2001-2014 OTRS AG, http://otrs.com/\n";
     print
         "usage: otrs.AddRole2Group.pl -g <GROUP> -r <ROLE> [-R<READ> -M<MOVE_INTO> -C<CREATE> -N<NOTE> -O<OWNER> -P<PRIORITY> -W<RW>] \n";
     print "For Options: R,M,C,N,O,P,W setting to 0 or 1 is expected \n";
@@ -70,25 +63,19 @@ if ( !$Opts{g} ) {
     exit 1;
 }
 
-# check for any permissions
-if (
-    !(
-        $Opts{R}
-        ||
-        $Opts{M} ||
-        $Opts{C} ||
-        $Opts{N} ||
-        $Opts{O} ||
-        $Opts{P} ||
-        $Opts{W}
-    )
-    )
-{
-    print STDERR "ERROR: Needs at least one permission being set\n";
-    exit 1;
-}
+# create common objects
+my %CommonObject = ();
+$CommonObject{ConfigObject} = Kernel::Config->new(%CommonObject);
+$CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
+$CommonObject{LogObject}    = Kernel::System::Log->new(
+    LogPrefix => 'OTRS-otrs.AddRole2Group.pl',
+    %CommonObject,
+);
+$CommonObject{MainObject}  = Kernel::System::Main->new(%CommonObject);
+$CommonObject{DBObject}    = Kernel::System::DB->new(%CommonObject);
+$CommonObject{GroupObject} = Kernel::System::Group->new(%CommonObject);
 
-#check Group
+# check group
 my $GroupID = $CommonObject{GroupObject}->GroupLookup( Group => $Opts{g} );
 if ( !$GroupID ) {
     print STDERR "ERROR: Found no GroupID for $Opts{g}\n";
@@ -124,6 +111,6 @@ if (
     exit 1;
 }
 else {
-    print "Added Group '$Opts{g}' to Role '$Opts{r}'.\n";
+    print "Added Group '$Opts{g} to Role '$Opts{r}'.'\n";
     exit(0);
 }
