@@ -1,6 +1,9 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -w
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# otrs.MarkTicketAsSeen.pl - set all ticket to seen
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# --
+# $Id: otrs.MarkTicketAsSeen.pl,v 1.4 2011-11-16 09:02:13 mb Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,26 +12,27 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 use strict;
 use warnings;
 
+# use ../ as lib location
 use File::Basename;
 use FindBin qw($RealBin);
 use lib dirname($RealBin);
-use lib dirname($RealBin) . '/Kernel/cpan-lib';
-use lib dirname($RealBin) . '/Custom';
+
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.4 $) [1];
 
 use Getopt::Std;
-
 use Kernel::Config;
 use Kernel::System::Encode;
 use Kernel::System::Log;
@@ -42,8 +46,8 @@ use Kernel::System::Ticket;
 my %Opts = ();
 getopts( 'ha', \%Opts );
 if ( $Opts{h} ) {
-    print "otrs.MarkTicketAsSeen.pl - mark tickets as seen by the agent\n";
-    print "Copyright (C) 2001-2017 OTRS AG, http://otrs.com/\n\n";
+    print "otrs.MarkTicketAsSeen.pl <Revision $VERSION> - mark tickets as seen by the agent\n";
+    print "Copyright (C) 2001-2014 OTRS AG, http://otrs.com/\n\n";
     print "usage: otrs.MarkTicketAsSeen.pl [-a]\n\n";
     print "If you pass '-a' it will update ALL tickets, otherwise only non-closed\n";
     print "tickets will be updated.\n";
