@@ -1,9 +1,9 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl
 # --
 # scripts/backup.pl - the backup script
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
-# $Id: backup.pl,v 1.25 2011-01-10 15:06:19 martin Exp $
+# $Id: backup.pl,v 1.25.4.2 2013-01-18 14:52:57 mg Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -17,7 +17,7 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -31,7 +31,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.25 $) [1];
+$VERSION = qw($Revision: 1.25.4.2 $) [1];
 
 use Getopt::Std;
 use Kernel::Config;
@@ -46,15 +46,14 @@ use Date::Pcalc qw(Today Today_and_Now Add_Delta_Days);
 my %Opts;
 my $Compress    = '';
 my $CompressCMD = '';
-my $FullBackup  = 0;
 my $DB          = '';
 my $DBDump      = '';
 getopt( 'hcrtd', \%Opts );
 if ( exists $Opts{h} ) {
     print "backup.pl <Revision $VERSION> - backup script\n";
-    print "Copyright (C) 2001-2011 OTRS AG, http://otrs.org/\n";
+    print "Copyright (C) 2001-2014 OTRS AG, http://otrs.com/\n";
     print
-        "usage: backup.pl -d /data_backup_dir/ [-c gzip|bzip2] [-r 30] [-t fullbackup|nofullbackup]\n";
+        "usage: backup.pl -d /data_backup_dir/ [-c gzip|bzip2] [-r 30] [-t fullbackup|nofullbackup|dbonly]\n";
     exit 1;
 }
 
@@ -79,7 +78,13 @@ else {
 }
 
 # check backup type
-if ( $Opts{t} && $Opts{t} =~ m/no/i ) {
+my $DBOnlyBackup = 0;
+my $FullBackup   = 0;
+
+if ( $Opts{t} && $Opts{t} eq 'dbonly' ) {
+    $DBOnlyBackup = 1;
+}
+elsif ( $Opts{t} && $Opts{t} eq 'nofullbackup' ) {
     $FullBackup = 0;
 }
 else {
@@ -152,6 +157,7 @@ if ( $Opts{r} ) {
         Directory => $Opts{d},
         Filter    => '*',
     );
+
     for my $Directory (@Directories) {
         my $Leave = 0;
         for my $Data ( keys %LeaveBackups ) {
@@ -178,7 +184,7 @@ if ( $Opts{r} ) {
                 print "done\n";
             }
             else {
-                print "failed\n";
+                die "failed\n";
             }
         }
     }
@@ -192,8 +198,7 @@ my ( $s, $m, $h, $D, $M, $Y ) = $CommonObject{TimeObject}->SystemTime2Date(
 );
 my $Directory = "$Opts{d}/$Y-$M-$D" . "_" . "$h-$m";
 if ( !mkdir($Directory) ) {
-    print STDERR "ERROR: Can't create directory: $Directory: $!\n";
-    exit 1;
+    die "ERROR: Can't create directory: $Directory: $!\n";
 }
 
 # backup Kernel/Config.pm
@@ -207,39 +212,45 @@ if (
     print "done\n";
 }
 else {
-    print "failed\n";
+    die "failed\n";
 }
 
 # backup application
-if ($FullBackup) {
-    print "Backup $Directory/Application.tar.gz ... ";
-    if ( !system("tar -czf $Directory/Application.tar.gz .") ) {
-        print "done\n";
-    }
-    else {
-        print "failed\n";
-    }
+if ($DBOnlyBackup) {
+    print "Backup of filesystem data disabled by parameter dbonly ... \n";
 }
-
-# backup vardir
 else {
-    print "Backup $Directory/VarDir.tar.gz ... ";
-    if ( !system("tar -czf $Directory/VarDir.tar.gz var/") ) {
-        print "done\n";
+    if ($FullBackup) {
+        print "Backup $Directory/Application.tar.gz ... ";
+        my $Excludes = "--exclude=var/tmp --exclude=js-cache --exclude=css-cache ";
+        if ( !system("tar $Excludes -czf $Directory/Application.tar.gz .") ) {
+            print "done\n";
+        }
+        else {
+            die "failed\n";
+        }
     }
-    else {
-        print "failed\n";
-    }
-}
 
-# backup datadir
-if ( $ArticleDir !~ m/\Q$Home\E/ ) {
-    print "Backup $Directory/DataDir.tar.gz ... ";
-    if ( !system("tar -czf $Directory/DataDir.tar.gz $ArticleDir") ) {
-        print "done\n";
-    }
+    # backup vardir
     else {
-        print "failed\n";
+        print "Backup $Directory/VarDir.tar.gz ... ";
+        if ( !system("tar -czf $Directory/VarDir.tar.gz var/") ) {
+            print "done\n";
+        }
+        else {
+            die "failed\n";
+        }
+    }
+
+    # backup datadir
+    if ( $ArticleDir !~ m/\Q$Home\E/ ) {
+        print "Backup $Directory/DataDir.tar.gz ... ";
+        if ( !system("tar -czf $Directory/DataDir.tar.gz $ArticleDir") ) {
+            print "done\n";
+        }
+        else {
+            die "failed\n";
+        }
     }
 }
 
@@ -258,7 +269,7 @@ if ( $DB =~ m/mysql/i ) {
         print "done\n";
     }
     else {
-        print "failed\n";
+        die "failed\n";
     }
 }
 else {
@@ -269,10 +280,10 @@ else {
         )
         )
     {
-        print "done\n";
+        die "done\n";
     }
     else {
-        print "failed\n";
+        die "failed\n";
     }
 }
 
@@ -282,5 +293,5 @@ if ( !system("$CompressCMD $Directory/DatabaseBackup.sql") ) {
     print "done\n";
 }
 else {
-    print "failed\n";
+    die "failed\n";
 }
